@@ -16,12 +16,12 @@ namespace attribute
 
 	struct FieldSetterWidget
 	{
-		typedef MyGUI::Widget BaseValueType;
+		using BaseValueType = MyGUI::Widget;
 
-		template <typename Type>
+		template<typename Type>
 		static Type* convert(BaseValueType* _value)
 		{
-			return _value == 0 ? 0 : _value->castType<Type>(false);
+			return _value == nullptr ? nullptr : _value->castType<Type>(false);
 		}
 	};
 
@@ -31,16 +31,9 @@ namespace attribute
 	ATTRIBUTE_FIELD(AttributeFieldWidgetName, _class, _field, _value)
 
 
-	DECLARE_ATTRIBUTE_CLASS(AttributeSize, MyGUI::IntSize);
-
-#define ATTRIBUTE_CLASS_SIZE(_class, _value) \
-	ATTRIBUTE_CLASS(AttributeSize, _class, _value)
-
-
 	DECLARE_ATTRIBUTE_CLASS(AttributeLayout, std::string);
 
-#define ATTRIBUTE_CLASS_LAYOUT(_class, _value) \
-	ATTRIBUTE_CLASS(AttributeLayout, _class, _value)
+#define ATTRIBUTE_CLASS_LAYOUT(_class, _value) ATTRIBUTE_CLASS(AttributeLayout, _class, _value)
 
 }
 
