@@ -13,22 +13,19 @@
 namespace demo
 {
 
-	class DemoKeeper :
-		public base::BaseDemoManager
+	class DemoKeeper : public base::BaseDemoManager
 	{
 	public:
-		DemoKeeper();
-
-		virtual void createScene();
-		virtual void destroyScene();
+		void createScene() override;
+		void destroyScene() override;
 
 	private:
 		void notifyColourAccept(ColourPanel* _sender);
-		virtual void setupResources();
+		void setupResources() override;
 
 	private:
-		ColourPanel* mColourPanel;
-		EditPanel* mEditPanel;
+		ColourPanel* mColourPanel{nullptr};
+		EditPanel* mEditPanel{nullptr};
 	};
 
 } // namespace demo
