@@ -13,24 +13,21 @@
 namespace demo
 {
 
-	class DemoKeeper :
-		public base::BaseDemoManager
+	class DemoKeeper : public base::BaseDemoManager
 	{
 	public:
-		DemoKeeper();
+		void createScene() override;
+		void destroyScene() override;
 
-		virtual void createScene();
-		virtual void destroyScene();
-
-		virtual void injectKeyPress(MyGUI::KeyCode _key, MyGUI::Char _text);
+		void injectKeyPress(MyGUI::KeyCode _key, MyGUI::Char _text) override;
 
 	private:
 		void command(const MyGUI::UString& _key, const MyGUI::UString& _value);
-		virtual void setupResources();
+		void setupResources() override;
 
 	private:
-		Console* mConsole;
-		MyGUI::EditBox* mEdit;
+		Console* mConsole{nullptr};
+		MyGUI::EditBox* mEdit{nullptr};
 	};
 
 } // namespace demo
