@@ -12,26 +12,23 @@
 namespace demo
 {
 
-	class DemoKeeper :
-		public base::BaseDemoManager
+	class DemoKeeper : public base::BaseDemoManager
 	{
 	public:
-		DemoKeeper();
-
-		virtual void createScene();
-		virtual void destroyScene();
+		void createScene() override;
+		void destroyScene() override;
 
 	private:
 		void notifyButtonPress(ControllerType _type, bool _complite);
-		virtual void setupResources();
+		void setupResources() override;
 
 	private:
-		State* mMenu1;
-		State* mMenu2;
-		State* mMenu3;
-		State* mMenu4;
+		State* mMenu1{nullptr};
+		State* mMenu2{nullptr};
+		State* mMenu3{nullptr};
+		State* mMenu4{nullptr};
 		ControllerType mType;
-		bool mIsAnim;
+		bool mIsAnim{false};
 	};
 
 } // namespace demo
