@@ -13,12 +13,10 @@
 namespace demo
 {
 
-	class ColourWindow :
-		public wraps::BaseLayout
+	class ColourWindow : public wraps::BaseLayout
 	{
 	public:
 		ColourWindow(MyGUI::Widget* _parent);
-		virtual ~ColourWindow();
 
 	private:
 		void notifyScrollChangePosition(MyGUI::ScrollBar* _sender, size_t _position);
