@@ -15,20 +15,17 @@
 namespace demo
 {
 
-	class DemoKeeper :
-		public base::BaseDemoManager
+	class DemoKeeper : public base::BaseDemoManager
 	{
 	public:
-		DemoKeeper();
-
-		virtual void createScene();
-		virtual void destroyScene();
+		void createScene() override;
+		void destroyScene() override;
 
 	private:
 		void notifyEventAction(MainPanel::TypeEvents _action, size_t _index);
 		void destroyWindows();
 		void createWindows();
-		virtual void setupResources();
+		void setupResources() override;
 		void removeRenderBoxes();
 		void createRenderBox(MyGUI::Canvas* _canvas);
 
@@ -36,13 +33,13 @@ namespace demo
 		void notifyFrameStart(float _time);
 
 	private:
-		EditorWindow* mEditorWindow;
-		MainPanel* mMainPanel;
-		InformationWindow* mInformationWindow;
-		ColourWindow* mColourWindow;
+		EditorWindow* mEditorWindow{nullptr};
+		MainPanel* mMainPanel{nullptr};
+		InformationWindow* mInformationWindow{nullptr};
+		ColourWindow* mColourWindow{nullptr};
 
 #ifdef MYGUI_OGRE_PLATFORM
-		Ogre::SceneNode* mNode;
+		Ogre::SceneNode* mNode{nullptr};
 #endif // MYGUI_OGRE_PLATFORM
 	};
 
