@@ -12,12 +12,11 @@
 namespace demo
 {
 
-	class InformationWindow :
-		public wraps::BaseLayout
+	class InformationWindow : public wraps::BaseLayout
 	{
 	public:
 		InformationWindow(MyGUI::Widget* _parent);
-		virtual ~InformationWindow();
+		~InformationWindow() override;
 
 	private:
 		void notifyFrameStart(float _time);
@@ -25,7 +24,7 @@ namespace demo
 
 	private:
 		MyGUI::EditBox* mInfo;
-		MyGUI::Widget* mFocus;
+		MyGUI::Widget* mFocus{nullptr};
 	};
 
 } // namespace demo
