@@ -12,8 +12,7 @@
 namespace demo
 {
 
-	class MainPanel :
-		public wraps::BaseLayout
+	class MainPanel : public wraps::BaseLayout
 	{
 	public:
 		enum TypeEvents
@@ -27,14 +26,14 @@ namespace demo
 	public:
 		MainPanel();
 
-		void addObject(const MyGUI::UString& _name);
+		void addObject(const MyGUI::UString& _name) const;
 
 	private:
-		void notifyMouseButtonClick(MyGUI::Widget* _sender);
-		void notifyComboAccept(MyGUI::ComboBox* _sender, size_t _index);
+		void notifyMouseButtonClick(MyGUI::Widget* _sender) const;
+		void notifyComboAccept(MyGUI::ComboBox* _sender, size_t _index) const;
 
 	public:
-		MyGUI::delegates::CDelegate2<TypeEvents, size_t> eventAction;
+		MyGUI::delegates::Delegate<TypeEvents, size_t> eventAction;
 
 		MyGUI::Button* mButtonNew;
 		MyGUI::Button* mButtonLoad;
