@@ -13,12 +13,11 @@
 namespace demo
 {
 
-	class ItemBox :
-		public wraps::BaseItemBox<CellView>
+	class ItemBox : public wraps::BaseItemBox<CellView>
 	{
 	public:
 		ItemBox(MyGUI::Widget* _parent);
-		virtual ~ItemBox();
+		~ItemBox() override;
 	};
 
 } // namespace demo
