@@ -13,11 +13,10 @@
 namespace demo
 {
 
-	class ItemBoxWindow :
-		public wraps::BaseLayout
+	class ItemBoxWindow : public wraps::BaseLayout
 	{
 	public:
-		ItemBoxWindow(const std::string& _layout);
+		ItemBoxWindow(std::string_view _layout);
 		ItemBox* getItemBox()
 		{
 			return mItemBox;
