@@ -19,27 +19,26 @@ namespace demo
 		EVENT_COUNT_DYNAMIC
 	};
 
-	typedef MyGUI::delegates::CDelegate2<int, size_t> EventHandle_EventDirector;
+	using EventHandle_EventDirector = MyGUI::delegates::Delegate<int, size_t>;
 
-	class PanelDirector :
-		public wraps::BasePanelViewItem
+	class PanelDirector : public wraps::BasePanelViewItem
 	{
 	public:
 		PanelDirector();
 
-		virtual void initialise();
-		virtual void shutdown();
+		void initialise() override;
+		void shutdown() override;
 
 		EventHandle_EventDirector eventChangePanels;
 
 	private:
 		void notifyMouseButtonClick(MyGUI::Widget* _sender);
-		void notifyComboAccept(MyGUI::ComboBox* _sender, size_t _index);
+		void notifyComboAccept(MyGUI::ComboBox* _sender, size_t _index) const;
 
 	private:
-		MyGUI::Button* mCheckShowStatic;
-		MyGUI::Button* mCheckShowDynamic;
-		MyGUI::ComboBox* mComboCount;
+		MyGUI::Button* mCheckShowStatic{nullptr};
+		MyGUI::Button* mCheckShowDynamic{nullptr};
+		MyGUI::ComboBox* mComboCount{nullptr};
 	};
 
 } // namespace demo
