@@ -12,14 +12,13 @@
 namespace demo
 {
 
-	class PanelDynamic :
-		public wraps::BasePanelViewItem
+	class PanelDynamic : public wraps::BasePanelViewItem
 	{
 	public:
 		PanelDynamic();
 
-		virtual void initialise();
-		virtual void shutdown();
+		void initialise() override;
+		void shutdown() override;
 
 		void setVisibleCount(size_t _count);
 
