@@ -11,8 +11,7 @@
 namespace demo
 {
 
-	class PanelViewCell :
-		public wraps::BasePanelViewCell
+	class PanelViewCell : public wraps::BasePanelViewCell
 	{
 	public:
 		PanelViewCell(MyGUI::Widget* _parent) :
@@ -22,11 +21,13 @@ namespace demo
 			assignWidget(mButtonMinimize, "button_Minimize");
 			assignWidget(mWidgetClient, "widget_Client");
 
-			mTextCaption->eventMouseButtonDoubleClick += MyGUI::newDelegate(this, &PanelViewCell::notifyMouseButtonDoubleClick);
-			mButtonMinimize->eventMouseButtonPressed += MyGUI::newDelegate(this, &PanelViewCell::notfyMouseButtonPressed);
+			mTextCaption->eventMouseButtonDoubleClick +=
+				MyGUI::newDelegate(this, &PanelViewCell::notifyMouseButtonDoubleClick);
+			mButtonMinimize->eventMouseButtonPressed +=
+				MyGUI::newDelegate(this, &PanelViewCell::notfyMouseButtonPressed);
 		}
 
-		virtual void setMinimized(bool _minimized)
+		void setMinimized(bool _minimized) override
 		{
 			wraps::BasePanelViewCell::setMinimized(_minimized);
 			mButtonMinimize->setStateSelected(isMinimized());
