@@ -11,19 +11,17 @@
 namespace demo
 {
 
-	class DemoKeeper :
-		public base::BaseDemoManager
+	class DemoKeeper : public base::BaseDemoManager
 	{
 	public:
-		DemoKeeper();
-		virtual void createScene();
-		virtual void destroyScene();
+		void createScene() override;
+		void destroyScene() override;
 
 	private:
-		virtual void setupResources();
+		void setupResources() override;
 
 	private:
-		MyGUI::TextBox* m_button;
+		MyGUI::TextBox* m_button{nullptr};
 	};
 
 } // namespace demo
