@@ -11,15 +11,12 @@
 namespace demo
 {
 
-	class DemoKeeper :
-		public base::BaseDemoManager
+	class DemoKeeper : public base::BaseDemoManager
 	{
 	public:
-		DemoKeeper();
-
-		virtual void createScene();
-		virtual void destroyScene();
-		virtual void setupResources();
+		void createScene() override;
+		void destroyScene() override;
+		void setupResources() override;
 
 	private:
 		void createDefaultScene();
@@ -27,7 +24,7 @@ namespace demo
 
 	private:
 #ifdef MYGUI_OGRE_PLATFORM
-		Ogre::SceneNode* mNode;
+		Ogre::SceneNode* mNode{nullptr};
 #endif // MYGUI_OGRE_PLATFORM
 	};
 
