@@ -11,25 +11,23 @@
 namespace demo
 {
 
-	class DemoKeeper :
-		public base::BaseDemoManager
+	class DemoKeeper : public base::BaseDemoManager
 	{
 	public:
-		DemoKeeper();
-		virtual void createScene();
-		virtual void destroyScene();
+		void createScene() override;
+		void destroyScene() override;
 
 	private:
 		void notifyComboAccept(MyGUI::ComboBox* _sender, size_t _index);
 		void createDemo(size_t _index);
 		void destroyDemo();
-		virtual void setupResources();
+		void setupResources() override;
 
 		void colourWidgets(MyGUI::Widget* _widget, const MyGUI::Colour& _colour);
 
 	private:
-		MyGUI::Widget* mDemoView;
-		MyGUI::ComboBox* mComboSkins;
+		MyGUI::Widget* mDemoView{nullptr};
+		MyGUI::ComboBox* mComboSkins{nullptr};
 	};
 
 } // namespace demo
