@@ -17,17 +17,14 @@
 namespace MyGUI
 {
 
-	typedef delegates::CMultiDelegate1<EditBox*> EventHandle_EditPtr;
+	using EventHandle_EditPtr = delegates::MultiDelegate<EditBox*>;
 
 	/** \brief @wpage{EditBox}
 		EditBox widget description should be here.
 	*/
-	class MYGUI_EXPORT EditBox :
-		public TextBox,
-		public ScrollViewBase,
-		public MemberObsolete<EditBox>
+	class MYGUI_EXPORT EditBox : public TextBox, public ScrollViewBase, public MemberObsolete<EditBox>
 	{
-		MYGUI_RTTI_DERIVED( EditBox )
+		MYGUI_RTTI_DERIVED(EditBox)
 
 	public:
 		EditBox();
@@ -46,7 +43,7 @@ namespace MyGUI
 
 		// возвращает текст с тегами
 		/** Get _count characters with tags from _start position */
-		UString getTextInterval(size_t _start, size_t _count);
+		UString getTextInterval(size_t _start, size_t _count) const;
 
 		/** Set selected text interval
 			@param _start of interval
@@ -58,13 +55,13 @@ namespace MyGUI
 		void deleteTextSelection();
 
 		/** Get selected text */
-		UString getTextSelection();
+		UString getTextSelection() const;
 
 		/** Is any text selected */
 		bool isTextSelection() const;
 
 		/** Colour selected text */
-		void setTextSelectionColour(const Colour& _value);
+		void setTextSelectionColour(const Colour& _colour);
 
 		/** Set text cursor position */
 		void setTextCursor(size_t _index);
@@ -73,14 +70,14 @@ namespace MyGUI
 
 
 		/** Set edit text applying tags */
-		virtual void setCaption(const UString& _value);
+		void setCaption(const UString& _value) override;
 		/** Get edit text with tags */
-		virtual const UString& getCaption();
+		const UString& getCaption() const override;
 
 		/** Set edit text without tags */
-		void setOnlyText(const UString& _value);
+		void setOnlyText(const UString& _text);
 		/** Get edit text without tags */
-		UString getOnlyText();
+		UString getOnlyText() const;
 
 		/** Get text length excluding tags
 			For example "Hello" length is 5
@@ -117,7 +114,7 @@ namespace MyGUI
 			Password mode: you see password chars (*** by default) instead text.\n
 			Disabled (false) by default.
 		*/
-		void setEditPassword(bool _value);
+		void setEditPassword(bool _password);
 		/** Get edit password mode flag */
 		bool getEditPassword() const;
 
@@ -139,9 +136,9 @@ namespace MyGUI
 		bool getEditStatic() const;
 
 		/** Set edit password character ('*' by default) */
-		void setPasswordChar(Char _value);
+		void setPasswordChar(Char _char);
 		/** Set edit password character ('*' by default). First character of string used. */
-		void setPasswordChar(const UString& _char);
+		void setPasswordChar(const UString& _value);
 		/** Get edit password character */
 		Char getPasswordChar() const;
 
@@ -164,25 +161,22 @@ namespace MyGUI
 		bool getTabPrinting() const;
 
 		/** Get invert selected text color property */
-		bool getInvertSelected();
+		bool getInvertSelected() const;
 		/** Enable or disable inverting color of selected text\n
 			Enabled (true) by default
 		*/
 		void setInvertSelected(bool _value);
 
-		//! @copydoc Widget::setPosition(const IntPoint& _value)
-		virtual void setPosition(const IntPoint& _value);
-		//! @copydoc Widget::setSize(const IntSize& _value)
-		virtual void setSize(const IntSize& _value);
-		//! @copydoc Widget::setCoord(const IntCoord& _value)
-		virtual void setCoord(const IntCoord& _value);
+		//! @copydoc Widget::setPosition(const IntPoint& _point)
+		void setPosition(const IntPoint& _point) override;
+		//! @copydoc Widget::setSize(const IntSize& _size)
+		void setSize(const IntSize& _size) override;
+		//! @copydoc Widget::setCoord(const IntCoord& _coord)
+		void setCoord(const IntCoord& _coord) override;
 
-		/** @copydoc Widget::setPosition(int _left, int _top) */
-		void setPosition(int _left, int _top);
-		/** @copydoc Widget::setSize(int _width, int _height) */
-		void setSize(int _width, int _height);
-		/** @copydoc Widget::setCoord(int _left, int _top, int _width, int _height) */
-		void setCoord(int _left, int _top, int _width, int _height);
+		using Widget::setPosition;
+		using Widget::setSize;
+		using Widget::setCoord;
 
 		/** Show VScroll when text size larger than EditBox */
 		void setVisibleVScroll(bool _value);
@@ -196,7 +190,7 @@ namespace MyGUI
 		*/
 		size_t getVScrollRange() const;
 		/** Get current position of vertical scroll (or 0 if no scroll) */
-		size_t getVScrollPosition();
+		size_t getVScrollPosition() const;
 		/** Set current position of vertical scroll */
 		void setVScrollPosition(size_t _index);
 
@@ -211,32 +205,34 @@ namespace MyGUI
 		*/
 		size_t getHScrollRange() const;
 		/** Get current position of horizontal scroll (or 0 if no scroll) */
-		size_t getHScrollPosition();
+		size_t getHScrollPosition() const;
 		/** Set current position of horizontal scroll */
 		void setHScrollPosition(size_t _index);
 
 
 		//! @copydoc TextBox::setFontName
-		virtual void setFontName(const std::string& _value);
+		void setFontName(std::string_view _value) override;
 		//! @copydoc TextBox::setFontHeight
-		virtual void setFontHeight(int _value);
+		void setFontHeight(int _value) override;
+		//! @copydoc TextBox::getFontHeight
+		int getFontHeight() const override;
 
 		//! @copydoc TextBox::setTextAlign
-		virtual void setTextAlign(Align _value);
+		void setTextAlign(Align _value) override;
 		//! @copydoc TextBox::setTextColour
-		virtual void setTextColour(const Colour& _value);
+		void setTextColour(const Colour& _value) override;
 
 		//! @copydoc TextBox::getTextRegion
-		virtual IntCoord getTextRegion();
+		IntCoord getTextRegion() const override;
 
 		//! @copydoc TextBox::getTextSize
-		virtual IntSize getTextSize();
+		IntSize getTextSize() const override;
 
 		//! @copydoc TextBox::setTextShadowColour
-		virtual void setTextShadowColour(const Colour& _value);
+		void setTextShadowColour(const Colour& _value) override;
 
 		//! @copydoc TextBox::setTextShadow
-		virtual void setTextShadow(bool _value);
+		void setTextShadow(bool _value) override;
 
 		/*events:*/
 		/** Event : Enter pressed (Ctrl+enter in multiline mode).\n
@@ -252,13 +248,13 @@ namespace MyGUI
 		EventPair<EventHandle_WidgetVoid, EventHandle_EditPtr> eventEditTextChange;
 
 	protected:
-		virtual void initialiseOverride();
-		virtual void shutdownOverride();
+		void initialiseOverride() override;
+		void shutdownOverride() override;
 
-		virtual void onMouseDrag(int _left, int _top, MouseButton _id);
-		virtual void onKeyLostFocus(Widget* _new);
-		virtual void onKeySetFocus(Widget* _old);
-		virtual void onKeyButtonPressed(KeyCode _key, Char _char);
+		void onMouseDrag(int _left, int _top, MouseButton _id) override;
+		void onKeyLostFocus(Widget* _new) override;
+		void onKeySetFocus(Widget* _old) override;
+		void onKeyButtonPressed(KeyCode _key, Char _char) override;
 
 		// потом убрать все нотифи в сраку
 		void notifyMouseSetFocus(Widget* _sender, Widget* _old);
@@ -277,15 +273,15 @@ namespace MyGUI
 
 		void eraseView();
 
-		virtual void setPropertyOverride(const std::string& _key, const std::string& _value);
+		void setPropertyOverride(std::string_view _key, std::string_view _value) override;
 
 	private:
 		// устанавливает текст
-		void setText(const UString& _text, bool _history);
+		void setText(const UString& _caption, bool _history);
 		// удаляет все что выделенно
 		bool deleteTextSelect(bool _history);
 		// вставляет текст в указанную позицию
-		void insertText(const UString& _text, size_t _index, bool _history);
+		void insertText(const UString& _text, size_t _start, bool _history);
 		// удаляет текст
 		void eraseText(size_t _start, size_t _count, bool _history);
 		// выделяет цветом выделение
@@ -315,62 +311,62 @@ namespace MyGUI
 		void commandResetHistory();
 		void saveInHistory(VectorChangeInfo* _info = nullptr);
 
-		// работа с буфером обмена
+		// clipboard commands
 		void commandCut();
-		void commandCopy();
-		void commandPast();
+		void commandCopy() const;
+		void commandPaste();
 
-		const UString& getRealString();
+		const UString& getRealString() const;
 
 		void setRealString(const UString& _caption);
 
 		void updateCursorPosition();
 
 		// размер данных
-		virtual IntSize getContentSize();
+		IntSize getContentSize() const override;
 		// смещение данных
-		virtual IntPoint getContentPosition();
-		virtual void setContentPosition(const IntPoint& _point);
+		IntPoint getContentPosition() const override;
+		void setContentPosition(const IntPoint& _point) override;
 		// размер окна, через которые видно данные
-		virtual IntSize getViewSize();
+		IntSize getViewSize() const override;
 		// размер на который прокручиваются данные при щелчке по скролу
-		virtual size_t getVScrollPage();
-		virtual size_t getHScrollPage();
+		size_t getVScrollPage() const override;
+		size_t getHScrollPage() const override;
 
-		virtual Align getContentAlign();
+		Align getContentAlign() const override;
 
 	protected:
 		// нажата ли кнопка
-		bool mIsPressed;
+		bool mIsPressed{false};
 		// в фокусе ли кнопка
-		bool mIsFocus;
+		bool mIsFocus{false};
 
-		bool mCursorActive;
-		float mCursorTimer;
-		float mActionMouseTimer;
+		bool mCursorActive{false};
+		float mCursorTimer{0};
+		float mActionMouseTimer{0};
 
 		// позиция курсора
-		size_t mCursorPosition;
+		size_t mCursorPosition{0};
 		// максимальное колличество
-		size_t mTextLength;
+		size_t mTextLength{0};
 
 		// выделение
-		size_t mStartSelect;
-		size_t mEndSelect;
+		size_t mStartSelect{ITEM_NONE};
+		size_t mEndSelect{0};
 
 		// списоки изменений для отмены и повтора
 		DequeUndoRedoInfo mVectorUndoChangeInfo;
 		DequeUndoRedoInfo mVectorRedoChangeInfo;
 
-		bool mMouseLeftPressed;
+		bool mMouseLeftPressed{false};
 
-		bool mModeReadOnly;
-		bool mModePassword;
-		bool mModeMultiline;
-		bool mModeStatic;
-		bool mModeWordWrap;
+		bool mModeReadOnly{false};
+		bool mModePassword{false};
+		bool mModeMultiline{false};
+		bool mModeStatic{false};
+		bool mModeWordWrap{false};
 
-		bool mTabPrinting;
+		bool mTabPrinting{false};
 
 		// настоящий текст, закрытый за звездочками
 		UString mPasswordText;
@@ -378,12 +374,12 @@ namespace MyGUI
 		// для поддержки режима статик, где курсор не нужен
 		std::string mOriginalPointer;
 
-		Char mCharPassword;
+		Char mCharPassword{'*'};
 
-		bool mOverflowToTheLeft;
+		bool mOverflowToTheLeft{false};
 		size_t mMaxTextLength;
 
-		ISubWidgetText* mClientText;
+		ISubWidgetText* mClientText{nullptr};
 	};
 
 } // namespace MyGUI
