@@ -10,15 +10,16 @@
 #include "MyGUI_Prerequest.h"
 #include "MyGUI_Types.h"
 #include "MyGUI_Delegate.h"
+#include "MyGUI_IObject.h"
 
 namespace MyGUI
 {
 
-	template <typename Type>
+	template<typename Type>
 	class GenericFactory
 	{
 	public:
-		typedef delegates::CDelegate1<IObject*&> Delegate;
+		using Delegate = delegates::Delegate<IObject*&>;
 		static typename Delegate::IDelegate* getFactory()
 		{
 			return newDelegate(createFromFactory);
