@@ -17,20 +17,16 @@ namespace MyGUI
 
 	class ITexture;
 
-	class MYGUI_EXPORT IFont :
-		public IResource
+	class MYGUI_EXPORT IFont : public IResource
 	{
-		MYGUI_RTTI_DERIVED( IFont )
+		MYGUI_RTTI_DERIVED(IFont)
 
 	public:
-		IFont() { }
-		virtual ~IFont() { }
+		virtual const GlyphInfo* getGlyphInfo(Char _id) const = 0;
 
-		virtual GlyphInfo* getGlyphInfo(Char _id) = 0;
+		virtual ITexture* getTextureFont() const = 0;
 
-		virtual ITexture* getTextureFont() = 0;
-
-		virtual int getDefaultHeight() = 0;
+		virtual int getDefaultHeight() const = 0;
 	};
 
 } // namespace MyGUI
