@@ -15,11 +15,10 @@ namespace MyGUI
 
 	class MYGUI_EXPORT IObject
 	{
-		MYGUI_RTTI_BASE( IObject )
+		MYGUI_RTTI_BASE(IObject)
 
 	public:
-		IObject() { }
-		virtual ~IObject() { }
+		virtual ~IObject() = default;
 	};
 
 } // namespace MyGUI
