@@ -4,8 +4,8 @@
  * (See accompanying file COPYING.MIT or copy at http://opensource.org/licenses/MIT)
  */
 
-#ifndef __MYGUI_I_RENDER_TARGET_H__
-#define __MYGUI_I_RENDER_TARGET_H__
+#ifndef MYGUI_I_RENDER_TARGET_H_
+#define MYGUI_I_RENDER_TARGET_H_
 
 #include "MyGUI_Prerequest.h"
 #include "MyGUI_RenderTargetInfo.h"
@@ -20,17 +20,16 @@ namespace MyGUI
 	class MYGUI_EXPORT IRenderTarget
 	{
 	public:
-		IRenderTarget() { }
-		virtual ~IRenderTarget() { }
+		virtual ~IRenderTarget() = default;
 
 		virtual void begin() = 0;
 		virtual void end() = 0;
 
 		virtual void doRender(IVertexBuffer* _buffer, ITexture* _texture, size_t _count) = 0;
 
-		virtual const RenderTargetInfo& getInfo() = 0;
+		virtual const RenderTargetInfo& getInfo() const = 0;
 	};
 
 } // namespace MyGUI
 
-#endif // __MYGUI_I_RENDER_TARGET_H__
+#endif // MYGUI_I_RENDER_TARGET_H_
