@@ -15,17 +15,17 @@
 namespace MyGUI
 {
 
-	class MYGUI_EXPORT ISerializable :
-		public IObject
+	class MYGUI_EXPORT ISerializable : public IObject
 	{
-		MYGUI_RTTI_DERIVED( ISerializable )
+		MYGUI_RTTI_DERIVED(ISerializable)
 
 	public:
-		ISerializable() { }
-		virtual ~ISerializable() { }
-
-		virtual void serialization(xml::ElementPtr _node, Version _version) { }
-		virtual void deserialization(xml::ElementPtr _node, Version _version) { }
+		virtual void serialization(xml::ElementPtr /*_node*/, Version /*_version*/)
+		{
+		}
+		virtual void deserialization(xml::ElementPtr /*_node*/, Version /*_version*/)
+		{
+		}
 	};
 
 } // namespace MyGUI
