@@ -13,17 +13,13 @@
 namespace MyGUI
 {
 
-	class MYGUI_EXPORT MainSkin :
-		public SubSkin
+	class MYGUI_EXPORT MainSkin : public SubSkin
 	{
-		MYGUI_RTTI_DERIVED( MainSkin )
+		MYGUI_RTTI_DERIVED(MainSkin)
 
 	public:
-		MainSkin();
-		virtual ~MainSkin();
-
 		/*internal:*/
-		virtual void _setAlign(const IntSize& _oldsize);
+		void _setAlign(const IntSize& _oldsize) override;
 	};
 
 } // namespace MyGUI
