@@ -18,52 +18,12 @@
 namespace MyGUI
 {
 
-	const size_t VERTEX_IN_QUAD = 6;
-	const size_t SIMPLETEXT_COUNT_VERTEX = 32 * VERTEX_IN_QUAD;
+	const size_t SIMPLETEXT_COUNT_VERTEX = 32 * VertexQuad::VertexCount;
 
 	EditText::EditText() :
-		ISubWidgetText(),
-		mEmptyView(false),
-		mCurrentColourNative(0x00FFFFFF),
-		mInverseColourNative(0x00000000),
-		mCurrentAlphaNative(0xFF000000),
-		mShadowColourNative(0x00000000),
-		mTextOutDate(false),
-		mTextAlign(Align::Default),
-		mColour(Colour::White),
-		mShadowColour(Colour::Black),
-		mAlpha(ALPHA_MAX),
-		mFont(nullptr),
-		mTexture(nullptr),
-		mFontHeight(0),
-		mBackgroundNormal(true),
-		mStartSelect(0),
-		mEndSelect(0),
-		mCursorPosition(0),
-		mVisibleCursor(false),
-		mInvertSelect(true),
-		mShadow(false),
-		mNode(nullptr),
-		mRenderItem(nullptr),
-		mCountVertex(SIMPLETEXT_COUNT_VERTEX),
-		mIsAddCursorWidth(true),
-		mShiftText(false),
-		mWordWrap(false),
-		mManualColour(false),
-		mOldWidth(0)
+		mCountVertex(SIMPLETEXT_COUNT_VERTEX)
 	{
 		mVertexFormat = RenderManager::getInstance().getVertexFormat();
-
-		mCurrentColourNative = texture_utility::toColourARGB(mColour);
-		texture_utility::convertColour(mCurrentColourNative, mVertexFormat);
-
-		mCurrentColourNative = (mCurrentColourNative & 0x00FFFFFF) | (mCurrentAlphaNative & 0xFF000000);
-		mShadowColourNative =  (mShadowColourNative & 0x00FFFFFF) | (mCurrentAlphaNative & 0xFF000000);
-		mInverseColourNative = mCurrentColourNative ^ 0x00FFFFFF;
-	}
-
-	EditText::~EditText()
-	{
 	}
 
 	void EditText::setVisible(bool _visible)
@@ -95,55 +55,43 @@ namespace MyGUI
 			}
 		}
 
-		// необходимо разобраться
-		bool need_update = true;//_update;
-
 		// первоначальное выравнивание
 		if (mAlign.isHStretch())
 		{
 			// растягиваем
 			mCoord.width = mCoord.width + (mCroppedParent->getWidth() - _oldsize.width);
-			need_update = true;
 			mIsMargin = true; // при изменении размеров все пересчитывать
 		}
 		else if (mAlign.isRight())
 		{
 			// двигаем по правому краю
 			mCoord.left = mCoord.left + (mCroppedParent->getWidth() - _oldsize.width);
-			need_update = true;
 		}
 		else if (mAlign.isHCenter())
 		{
 			// выравнивание по горизонтали без растяжения
 			mCoord.left = (mCroppedParent->getWidth() - mCoord.width) / 2;
-			need_update = true;
 		}
 
 		if (mAlign.isVStretch())
 		{
 			// растягиваем
 			mCoord.height = mCoord.height + (mCroppedParent->getHeight() - _oldsize.height);
-			need_update = true;
 			mIsMargin = true; // при изменении размеров все пересчитывать
 		}
 		else if (mAlign.isBottom())
 		{
 			// двигаем по нижнему краю
 			mCoord.top = mCoord.top + (mCroppedParent->getHeight() - _oldsize.height);
-			need_update = true;
 		}
 		else if (mAlign.isVCenter())
 		{
 			// выравнивание по вертикали без растяжения
 			mCoord.top = (mCroppedParent->getHeight() - mCoord.height) / 2;
-			need_update = true;
 		}
 
-		if (need_update)
-		{
-			mCurrentCoord = mCoord;
-			_updateView();
-		}
+		mCurrentCoord = mCoord;
+		_updateView();
 	}
 
 	void EditText::_updateView()
@@ -188,6 +136,7 @@ namespace MyGUI
 	void EditText::setCaption(const UString& _value)
 	{
 		mCaption = _value;
+		mUtf32Caption = mCaption.asUTF32();
 		mTextOutDate = true;
 
 		checkVertexSize();
@@ -198,8 +147,8 @@ namespace MyGUI
 
 	void EditText::checkVertexSize()
 	{
-		// если вершин не хватит, делаем реалок, с учетом выделения * 2 и курсора
-		size_t need = (mCaption.size() * (mShadow ? 3 : 2) + 2) * VERTEX_IN_QUAD;
+		// reallocate if we need more vertices (extra vertices for selection * 2 and cursor)
+		size_t need = (mUtf32Caption.size() * (mShadow ? 3 : 2) + 2) * VertexQuad::VertexCount;
 		if (mCountVertex < need)
 		{
 			mCountVertex = need + SIMPLETEXT_COUNT_VERTEX;
@@ -208,6 +157,11 @@ namespace MyGUI
 		}
 	}
 
+	unsigned int EditText::getMixedNativeAlpha(float secondAlpha) const
+	{
+		return (uint8)(mAlpha * secondAlpha * 255) << 24;
+	}
+
 	const UString& EditText::getCaption() const
 	{
 		return mCaption;
@@ -225,11 +179,9 @@ namespace MyGUI
 			return;
 
 		mColour = _value;
-		mCurrentColourNative = texture_utility::toColourARGB(mColour);
+		mCurrentColourNative = texture_utility::toNativeColour(mColour, mVertexFormat);
 
-		texture_utility::convertColour(mCurrentColourNative, mVertexFormat);
-
-		mCurrentColourNative = (mCurrentColourNative & 0x00FFFFFF) | (mCurrentAlphaNative & 0xFF000000);
+		mCurrentColourNative = (mCurrentColourNative & 0x00FFFFFF) | getMixedNativeAlpha(mColour.alpha);
 		mInverseColourNative = mCurrentColourNative ^ 0x00FFFFFF;
 
 		if (nullptr != mNode)
@@ -247,30 +199,24 @@ namespace MyGUI
 			return;
 		mAlpha = _value;
 
-		mCurrentAlphaNative = ((uint8)(mAlpha * 255) << 24);
-		mCurrentColourNative = (mCurrentColourNative & 0x00FFFFFF) | (mCurrentAlphaNative & 0xFF000000);
-		mShadowColourNative = (mShadowColourNative & 0x00FFFFFF) | (mCurrentAlphaNative & 0xFF000000);
+		mCurrentColourNative = (mCurrentColourNative & 0x00FFFFFF) | getMixedNativeAlpha(mColour.alpha);
+		mShadowColourNative = (mShadowColourNative & 0x00FFFFFF) | getMixedNativeAlpha(mShadowColour.alpha);
 		mInverseColourNative = mCurrentColourNative ^ 0x00FFFFFF;
 
 		if (nullptr != mNode)
 			mNode->outOfDate(mRenderItem);
 	}
 
-	float EditText::getAlpha() const
+	void EditText::setFontName(std::string_view _value)
 	{
-		return mAlpha;
-	}
-
-	void EditText::setFontName(const std::string& _value)
-	{
-		mTexture = 0;
+		mTexture = nullptr;
 		mFont = FontManager::getInstance().getByName(_value);
 		if (mFont != nullptr)
 		{
 			mTexture = mFont->getTextureFont();
 
-			// если надо, устанавливаем дефолтный размер шрифта
-			if (mFont->getDefaultHeight() != 0)
+			// set default font height
+			if (mFont->getDefaultHeight() != 0 && !mCustomFontHeight)
 			{
 				mFontHeight = mFont->getDefaultHeight();
 			}
@@ -296,14 +242,18 @@ namespace MyGUI
 			mNode->outOfDate(mRenderItem);
 	}
 
-	const std::string& EditText::getFontName() const
+	std::string_view EditText::getFontName() const
 	{
 		return mFont->getResourceName();
 	}
 
 	void EditText::setFontHeight(int _value)
 	{
-		mFontHeight = _value;
+		mCustomFontHeight = _value;
+		if (!mCustomFontHeight && mFont)
+			mFontHeight = mFont->getDefaultHeight();
+		else
+			mFontHeight = _value;
 		mTextOutDate = true;
 
 		if (nullptr != mNode)
@@ -415,7 +365,7 @@ namespace MyGUI
 		return mTextAlign;
 	}
 
-	IntSize EditText::getTextSize()
+	IntSize EditText::getTextSize() const
 	{
 		// если нуно обновить, или изменились пропорции экрана
 		if (mTextOutDate)
@@ -429,8 +379,8 @@ namespace MyGUI
 		if (mShadow)
 		{
 			if (!mIsAddCursorWidth)
-				size.width ++;
-			size.height ++;
+				size.width++;
+			size.height++;
 		}
 
 		return size;
@@ -454,7 +404,7 @@ namespace MyGUI
 		return mViewOffset;
 	}
 
-	size_t EditText::getCursorPosition(const IntPoint& _point)
+	size_t EditText::getCursorPosition(const IntPoint& _point) const
 	{
 		if (nullptr == mFont)
 			return 0;
@@ -470,10 +420,10 @@ namespace MyGUI
 		return mTextView.getCursorPosition(point);
 	}
 
-	IntCoord EditText::getCursorCoord(size_t _position)
+	IntCoord EditText::getCursorCoord(size_t _position) const
 	{
 		if (nullptr == mFont)
-			return IntCoord();
+			return {};
 
 		if (mTextOutDate)
 			updateRawData();
@@ -483,7 +433,7 @@ namespace MyGUI
 		point -= mViewOffset;
 		point += mCoord.point();
 
-		return IntCoord(point.left, point.top, 2, mFontHeight);
+		return {point.left, point.top, 2, mFontHeight};
 	}
 
 	void EditText::setShiftText(bool _value)
@@ -505,7 +455,7 @@ namespace MyGUI
 			mNode->outOfDate(mRenderItem);
 	}
 
-	void EditText::updateRawData()
+	void EditText::updateRawData() const
 	{
 		if (nullptr == mFont)
 			return;
@@ -521,7 +471,7 @@ namespace MyGUI
 				width -= 2;
 		}
 
-		mTextView.update(mCaption, mFont, mFontHeight, mTextAlign, mVertexFormat, width);
+		mTextView.update(mUtf32Caption, mFont, mFontHeight, mTextAlign, mVertexFormat, width);
 	}
 
 	void EditText::setStateData(IStateInfo* _data)
@@ -558,19 +508,20 @@ namespace MyGUI
 
 		FloatRect vertexRect;
 
-		const FloatRect& selectedUVRect = mFont->getGlyphInfo(mBackgroundNormal ? FontCodeType::Selected : FontCodeType::SelectedBack)->uvRect;
+		const FloatRect& selectedUVRect =
+			mFont->getGlyphInfo(mBackgroundNormal ? FontCodeType::Selected : FontCodeType::SelectedBack)->uvRect;
 
 		size_t index = 0;
 
-		for (VectorLineInfo::const_iterator line = textViewData.begin(); line != textViewData.end(); ++line)
+		for (const auto& line : textViewData)
 		{
-			float left = (float)(line->offset - mViewOffset.left + mCoord.left);
+			float left = (float)(line.offset - mViewOffset.left + mCoord.left);
 
-			for (VectorCharInfo::const_iterator sim = line->simbols.begin(); sim != line->simbols.end(); ++sim)
+			for (const auto& sym : line.symbols)
 			{
-				if (sim->isColour())
+				if (sym.isColour())
 				{
-					colour = sim->getColour() | (colour & 0xFF000000);
+					colour = sym.getColour() | (colour & 0xFF000000);
 					inverseColour = colour ^ 0x00FFFFFF;
 					selectedColour = mInvertSelect ? inverseColour : colour | 0x00FFFFFF;
 					continue;
@@ -579,7 +530,7 @@ namespace MyGUI
 				// смещение текстуры для фона
 				bool select = index >= mStartSelect && index < mEndSelect;
 
-				float fullAdvance = sim->getBearingX() + sim->getAdvance();
+				float fullAdvance = sym.getBearingX() + sym.getAdvance();
 
 				// Render the selection, if any, first.
 				if (select)
@@ -592,21 +543,27 @@ namespace MyGUI
 				// Render the glyph shadow, if any.
 				if (mShadow)
 				{
-					vertexRect.left = left + sim->getBearingX() + 1.0f;
-					vertexRect.top = top + sim->getBearingY() + 1.0f;
-					vertexRect.right = vertexRect.left + sim->getWidth();
-					vertexRect.bottom = vertexRect.top + sim->getHeight();
+					vertexRect.left = left + sym.getBearingX() + 1.0f;
+					vertexRect.top = top + sym.getBearingY() + 1.0f;
+					vertexRect.right = vertexRect.left + sym.getWidth();
+					vertexRect.bottom = vertexRect.top + sym.getHeight();
 
-					drawGlyph(renderTargetInfo, vertex, vertexCount, vertexRect, sim->getUVRect(), mShadowColourNative);
+					drawGlyph(renderTargetInfo, vertex, vertexCount, vertexRect, sym.getUVRect(), mShadowColourNative);
 				}
 
 				// Render the glyph itself.
-				vertexRect.left = left + sim->getBearingX();
-				vertexRect.top = top + sim->getBearingY();
-				vertexRect.right = vertexRect.left + sim->getWidth();
-				vertexRect.bottom = vertexRect.top + sim->getHeight();
+				vertexRect.left = left + sym.getBearingX();
+				vertexRect.top = top + sym.getBearingY();
+				vertexRect.right = vertexRect.left + sym.getWidth();
+				vertexRect.bottom = vertexRect.top + sym.getHeight();
 
-				drawGlyph(renderTargetInfo, vertex, vertexCount, vertexRect, sim->getUVRect(), (!select || !mInvertSelect) ? colour : inverseColour);
+				drawGlyph(
+					renderTargetInfo,
+					vertex,
+					vertexCount,
+					vertexRect,
+					sym.getUVRect(),
+					(!select || !mInvertSelect) ? colour : inverseColour);
 
 				left += fullAdvance;
 				++index;
@@ -620,10 +577,20 @@ namespace MyGUI
 		if (mVisibleCursor)
 		{
 			IntPoint point = mTextView.getCursorPoint(mCursorPosition) - mViewOffset + mCoord.point();
-			GlyphInfo* cursorGlyph = mFont->getGlyphInfo(static_cast<Char>(FontCodeType::Cursor));
-			vertexRect.set((float)point.left, (float)point.top, (float)point.left + cursorGlyph->width, (float)(point.top + mFontHeight));
+			const GlyphInfo* cursorGlyph = mFont->getGlyphInfo(static_cast<Char>(FontCodeType::Cursor));
+			vertexRect.set(
+				(float)point.left,
+				(float)point.top,
+				(float)point.left + cursorGlyph->width,
+				(float)(point.top + mFontHeight));
 
-			drawGlyph(renderTargetInfo, vertex, vertexCount, vertexRect, cursorGlyph->uvRect, mCurrentColourNative | 0x00FFFFFF);
+			drawGlyph(
+				renderTargetInfo,
+				vertex,
+				vertexCount,
+				vertexRect,
+				cursorGlyph->uvRect,
+				mCurrentColourNative | 0x00FFFFFF);
 		}
 
 		// колличество реально отрисованных вершин
@@ -664,11 +631,9 @@ namespace MyGUI
 	void EditText::setShadowColour(const Colour& _value)
 	{
 		mShadowColour = _value;
-		mShadowColourNative = texture_utility::toColourARGB(mShadowColour);
+		mShadowColourNative = texture_utility::toNativeColour(mShadowColour, mVertexFormat);
 
-		texture_utility::convertColour(mShadowColourNative, mVertexFormat);
-
-		mShadowColourNative = (mShadowColourNative & 0x00FFFFFF) | (mCurrentAlphaNative & 0xFF000000);
+		mShadowColourNative = (mShadowColourNative & 0x00FFFFFF) | getMixedNativeAlpha(mShadowColour.alpha);
 
 		if (nullptr != mNode)
 			mNode->outOfDate(mRenderItem);
@@ -729,8 +694,8 @@ namespace MyGUI
 		_vertex[4].u = _textureRect.right;
 		_vertex[4].v = _textureRect.bottom;
 
-		_vertex += VERTEX_IN_QUAD;
-		_vertexCount += VERTEX_IN_QUAD;
+		_vertex += VertexQuad::VertexCount;
+		_vertexCount += VertexQuad::VertexCount;
 	}
 
 	void EditText::drawGlyph(
@@ -802,13 +767,16 @@ namespace MyGUI
 		}
 
 		float pix_left = mCroppedParent->getAbsoluteLeft() - _renderTargetInfo.leftOffset + _vertexRect.left;
-		float pix_top = mCroppedParent->getAbsoluteTop() - _renderTargetInfo.topOffset + (mShiftText ? 1.0f : 0.0f) + _vertexRect.top;
+		float pix_top = mCroppedParent->getAbsoluteTop() - _renderTargetInfo.topOffset + (mShiftText ? 1.0f : 0.0f) +
+			_vertexRect.top;
 
 		FloatRect vertexRect(
 			((_renderTargetInfo.pixScaleX * pix_left + _renderTargetInfo.hOffset) * 2.0f) - 1.0f,
 			-(((_renderTargetInfo.pixScaleY * pix_top + _renderTargetInfo.vOffset) * 2.0f) - 1.0f),
-			((_renderTargetInfo.pixScaleX * (pix_left + _vertexRect.width()) + _renderTargetInfo.hOffset) * 2.0f) - 1.0f,
-			-(((_renderTargetInfo.pixScaleY * (pix_top + _vertexRect.height()) + _renderTargetInfo.vOffset) * 2.0f) - 1.0f));
+			((_renderTargetInfo.pixScaleX * (pix_left + _vertexRect.width()) + _renderTargetInfo.hOffset) * 2.0f) -
+				1.0f,
+			-(((_renderTargetInfo.pixScaleY * (pix_top + _vertexRect.height()) + _renderTargetInfo.vOffset) * 2.0f) -
+			  1.0f));
 
 		drawQuad(_vertex, _vertexCount, vertexRect, mNode->getNodeDepth(), _textureRect, _colour);
 	}
