@@ -11,24 +11,12 @@
 #include "MyGUI_ResourceSkin.h"
 #include "MyGUI_InputManager.h"
 #include "MyGUI_Gui.h"
-#include "MyGUI_WidgetTranslate.h"
 #include "MyGUI_WidgetManager.h"
 
 namespace MyGUI
 {
 
-	ItemBox::ItemBox() :
-		mCountItemInLine(0),
-		mCountLines(0),
-		mFirstVisibleIndex(0),
-		mFirstOffsetIndex(0),
-		mIndexSelect(ITEM_NONE),
-		mIndexActive(ITEM_NONE),
-		mIndexAccept(ITEM_NONE),
-		mIndexRefuse(ITEM_NONE),
-		mIsFocus(false),
-		mItemDrag(nullptr),
-		mAlignVert(true)
+	ItemBox::ItemBox()
 	{
 		mChangeContentByResize = true;
 	}
@@ -45,14 +33,12 @@ namespace MyGUI
 		if (isUserString("DragLayer"))
 			mDragLayer = getUserString("DragLayer");
 
-		///@wskin_child{ItemBox, Widget, Client} Клиентская зона.
-		assignWidget(mClient, "Client");
-		if (mClient != nullptr)
+		assignWidget(mScrollViewClient, "Client");
+		if (getClientWidget() != nullptr)
 		{
-			mClient->eventMouseWheel += newDelegate(this, &ItemBox::notifyMouseWheel);
-			mClient->eventMouseButtonPressed += newDelegate(this, &ItemBox::notifyMouseButtonPressed);
-			mClient->eventMouseButtonReleased += newDelegate(this, &ItemBox::notifyMouseButtonReleased);
-			setWidgetClient(mClient);
+			getClientWidget()->eventMouseWheel += newDelegate(this, &ItemBox::notifyMouseWheel);
+			getClientWidget()->eventMouseButtonPressed += newDelegate(this, &ItemBox::notifyMouseButtonPressed);
+			getClientWidget()->eventMouseButtonReleased += newDelegate(this, &ItemBox::notifyMouseButtonReleased);
 		}
 
 		///@wskin_child{ItemBox, ScrollBar, VScroll} Вертикальная полоса прокрутки.
@@ -70,8 +56,8 @@ namespace MyGUI
 		}
 
 		// подписываем клиент для драгэндропа
-		if (mClient != nullptr)
-			mClient->_setContainer(this);
+		if (getClientWidget() != nullptr)
+			getClientWidget()->_setContainer(this);
 
 		requestItemSize();
 
@@ -83,7 +69,6 @@ namespace MyGUI
 	{
 		mVScroll = nullptr;
 		mHScroll = nullptr;
-		mClient = nullptr;
 
 		Base::shutdownOverride();
 	}
@@ -113,7 +98,9 @@ namespace MyGUI
 		requestCoordItem(this, coord, false);
 
 		mSizeItem = coord.size();
-		MYGUI_ASSERT((mSizeItem.width > 0 && mSizeItem.height > 0), "(mSizeItem.width > 0 && mSizeItem.height > 0)  at requestCoordWidgetItem");
+		MYGUI_ASSERT(
+			(mSizeItem.width > 0 && mSizeItem.height > 0),
+			"(mSizeItem.width > 0 && mSizeItem.height > 0)  at requestCoordWidgetItem");
 	}
 
 	void ItemBox::updateFromResize()
@@ -146,17 +133,20 @@ namespace MyGUI
 		for (size_t pos = start; pos < count; ++pos, ++index)
 		{
 			// дальше нет айтемов
-			if (pos >= mItemsInfo.size()) break;
+			if (pos >= mItemsInfo.size())
+				break;
 
 			Widget* item = getItemWidget(index);
 			if (mAlignVert)
 			{
-				item->setPosition(((int)index % mCountItemInLine) * mSizeItem.width - mContentPosition.left,
-					(((int)index / mCountItemInLine) * mSizeItem.height)  - mFirstOffsetIndex);
+				item->setPosition(
+					((int)index % mCountItemInLine) * mSizeItem.width - mContentPosition.left,
+					(((int)index / mCountItemInLine) * mSizeItem.height) - mFirstOffsetIndex);
 			}
 			else
 			{
-				item->setPosition((((int)index / mCountItemInLine) * mSizeItem.width)  - mFirstOffsetIndex,
+				item->setPosition(
+					(((int)index / mCountItemInLine) * mSizeItem.width) - mFirstOffsetIndex,
 					((int)index % mCountItemInLine) * mSizeItem.height - mContentPosition.top);
 			}
 
@@ -168,14 +158,13 @@ namespace MyGUI
 				IBDrawItemInfo data(pos, mIndexSelect, mIndexActive, mIndexAccept, mIndexRefuse, true, false);
 				requestDrawItem(this, item, data);
 			}
-
 		}
 
 		// все виджеты еще есть, то их надо бы скрыть
 		while (index < mVectorItems.size())
 		{
 			mVectorItems[index]->setVisible(false);
-			index ++;
+			index++;
 		}
 	}
 
@@ -186,7 +175,10 @@ namespace MyGUI
 		{
 			requestItemSize();
 
-			Widget* item = _getClientWidget()->createWidget<Widget>("Default", IntCoord(0, 0, mSizeItem.width, mSizeItem.height), Align::Default);
+			Widget* item = _getClientWidget()->createWidget<Widget>(
+				"Default",
+				IntCoord(0, 0, mSizeItem.width, mSizeItem.height),
+				Align::Default);
 
 			// вызываем запрос на создание виджета
 			requestCreateWidgetItem(this, item);
@@ -259,24 +251,23 @@ namespace MyGUI
 		const IntPoint& point = InputManager::getInstance().getMousePositionByLayer();
 
 		// сначала проверяем клиентскую зону
-		const IntRect& rect = _getClientAbsoluteRect();
-		if ((point.left < rect.left) || (point.left > rect.right) || (point.top < rect.top) || (point.top > rect.bottom))
+		const IntRect& rect = _getClientWidget()->getAbsoluteRect();
+		if ((point.left < rect.left) || (point.left > rect.right) || (point.top < rect.top) ||
+			(point.top > rect.bottom))
 		{
 			return;
 		}
 
-		for (size_t pos = 0; pos < mVectorItems.size(); ++pos)
+		for (const auto& item : mVectorItems)
 		{
-			Widget* item = mVectorItems[pos];
 			const IntRect& abs_rect = item->getAbsoluteRect();
-			if ((point.left >= abs_rect.left) && (point.left <= abs_rect.right) && (point.top >= abs_rect.top) && (point.top <= abs_rect.bottom))
+			if ((point.left >= abs_rect.left) && (point.left <= abs_rect.right) && (point.top >= abs_rect.top) &&
+				(point.top <= abs_rect.bottom))
 			{
-
 				size_t index = calcIndexByWidget(item);
 				// при переборе индекс может быть больше, так как может создасться сколько угодно
 				if (index < mItemsInfo.size())
 				{
-
 					mIndexActive = index;
 					IBDrawItemInfo data(index, mIndexSelect, mIndexActive, mIndexAccept, mIndexRefuse, false, false);
 
@@ -288,7 +279,7 @@ namespace MyGUI
 		}
 	}
 
-	size_t ItemBox::_getItemIndex(Widget* _item)
+	size_t ItemBox::_getItemIndex(Widget* _item) const
 	{
 		if (_item == _getClientWidget())
 			return ITEM_NONE;
@@ -300,10 +291,11 @@ namespace MyGUI
 
 	void ItemBox::_setContainerItemInfo(size_t _index, bool _set, bool _accept)
 	{
-		if (_index == ITEM_NONE) return;
+		if (_index == ITEM_NONE)
+			return;
 		MYGUI_ASSERT_RANGE(_index, mItemsInfo.size(), "ItemBox::_setContainerItemInfo");
 
-		mIndexAccept = (_set && _accept ) ? _index : ITEM_NONE;
+		mIndexAccept = (_set && _accept) ? _index : ITEM_NONE;
 		mIndexRefuse = (_set && !_accept) ? _index : ITEM_NONE;
 
 		size_t start = (size_t)(mFirstVisibleIndex * mCountItemInLine);
@@ -317,7 +309,7 @@ namespace MyGUI
 	void ItemBox::setItemDataAt(size_t _index, Any _data)
 	{
 		MYGUI_ASSERT_RANGE(_index, mItemsInfo.size(), "ItemBox::setItemData");
-		mItemsInfo[_index].data = _data;
+		mItemsInfo[_index].data = std::move(_data);
 
 		size_t start = (size_t)(mFirstVisibleIndex * mCountItemInLine);
 		if ((_index >= start) && (_index < (start + mVectorItems.size())))
@@ -329,13 +321,13 @@ namespace MyGUI
 		_resetContainer(true);
 	}
 
-	void ItemBox::insertItemAt(size_t _index, Any _data)
+	void ItemBox::insertItemAt(size_t _index, Any _data, bool update)
 	{
 		MYGUI_ASSERT_RANGE_INSERT(_index, mItemsInfo.size(), "ItemBox::insertItemAt");
-		if (_index == ITEM_NONE) _index = mItemsInfo.size();
+		if (_index == ITEM_NONE)
+			_index = mItemsInfo.size();
 
 		_resetContainer(false);
-
 		resetCurrentActiveItem();
 
 		mItemsInfo.insert(mItemsInfo.begin() + _index, ItemDataInfo(_data));
@@ -345,19 +337,22 @@ namespace MyGUI
 		{
 			if (mIndexSelect >= _index)
 			{
-				mIndexSelect ++;
+				mIndexSelect++;
 			}
 		}
 
-		updateScrollSize();
-		updateScrollPosition();
+		if (update)
+		{
+			updateScrollSize();
+			updateScrollPosition();
 
-		findCurrentActiveItem();
+			findCurrentActiveItem();
 
-		_updateAllVisible(true);
+			_updateAllVisible(true);
+		}
 	}
 
-	void ItemBox::removeItemAt(size_t _index)
+	void ItemBox::removeItemAt(size_t _index, bool update)
 	{
 		MYGUI_ASSERT_RANGE(_index, mItemsInfo.size(), "ItemBox::removeItemAt");
 
@@ -375,16 +370,19 @@ namespace MyGUI
 			}
 			else if ((mIndexSelect > _index) || (mIndexSelect == mItemsInfo.size()))
 			{
-				mIndexSelect --;
+				mIndexSelect--;
 			}
 		}
 
-		updateScrollSize();
-		updateScrollPosition();
+		if (update)
+		{
+			updateScrollSize();
+			updateScrollPosition();
 
-		findCurrentActiveItem();
+			findCurrentActiveItem();
 
-		_updateAllVisible(true);
+			_updateAllVisible(true);
+		}
 	}
 
 	void ItemBox::removeAllItems()
@@ -419,7 +417,8 @@ namespace MyGUI
 	void ItemBox::setIndexSelected(size_t _index)
 	{
 		MYGUI_ASSERT_RANGE_AND_NONE(_index, mItemsInfo.size(), "ItemBox::setIndexSelected");
-		if (_index == mIndexSelect) return;
+		if (_index == mIndexSelect)
+			return;
 
 		size_t start = (size_t)(mFirstVisibleIndex * mCountItemInLine);
 
@@ -445,7 +444,6 @@ namespace MyGUI
 				requestDrawItem(this, mVectorItems[_index - start], data);
 			}
 		}
-
 	}
 
 	void ItemBox::notifyMouseButtonDoubleClick(Widget* _sender)
@@ -475,10 +473,11 @@ namespace MyGUI
 		eventNotifyItem(this, IBNotifyItemData(getIndexByWidget(_sender), IBNotifyItemData::KeyReleased, _key));
 	}
 
-	size_t ItemBox::getIndexByWidget(Widget* _widget)
+	size_t ItemBox::getIndexByWidget(Widget* _widget) const
 	{
 		MYGUI_ASSERT(_widget, "ItemBox::getIndexByWidget : Widget == nullptr");
-		if (_widget == _getClientWidget()) return ITEM_NONE;
+		if (_widget == _getClientWidget())
+			return ITEM_NONE;
 		MYGUI_ASSERT(_widget->getParent() == _getClientWidget(), "ItemBox::getIndexByWidget : Widget is not child");
 
 		size_t index = calcIndexByWidget(_widget);
@@ -487,15 +486,15 @@ namespace MyGUI
 		return index;
 	}
 
-	size_t ItemBox::_getContainerIndex(const IntPoint& _point)
+	size_t ItemBox::_getContainerIndex(const IntPoint& _point) const
 	{
-		for (VectorWidgetPtr::iterator iter = mVectorItems.begin(); iter != mVectorItems.end(); ++iter)
+		for (const auto& item : mVectorItems)
 		{
-			if ((*iter)->getVisible())
+			if (item->getVisible())
 			{
-				if ((*iter)->getAbsoluteRect().inside(_point))
+				if (item->getAbsoluteRect().inside(_point))
 				{
-					return getIndexByWidget(*iter);
+					return getIndexByWidget(item);
 				}
 			}
 		}
@@ -507,25 +506,26 @@ namespace MyGUI
 		// обязательно у базового
 		Base::_resetContainer(_update);
 
-		if ( ! _update)
+		if (!_update)
 		{
 			WidgetManager& instance = WidgetManager::getInstance();
-			for (VectorWidgetPtr::iterator iter = mVectorItems.begin(); iter != mVectorItems.end(); ++iter)
+			for (auto& vectorItem : mVectorItems)
 			{
-				instance.unlinkFromUnlinkers(*iter);
+				instance.unlinkFromUnlinkers(vectorItem);
 			}
 		}
 	}
 
 	Widget* ItemBox::getWidgetByIndex(size_t _index)
 	{
-		for (VectorWidgetPtr::iterator iter = mVectorItems.begin(); iter != mVectorItems.end(); ++iter)
+		for (const auto& vectorItem : mVectorItems)
 		{
-			if ((*iter)->getVisible())
+			if (vectorItem->getVisible())
 			{
-				size_t index = getIndexByWidget(*iter);
+				size_t index = getIndexByWidget(vectorItem);
 
-				if (index == _index) return (*iter);
+				if (index == _index)
+					return vectorItem;
 			}
 		}
 		return nullptr;
@@ -548,7 +548,8 @@ namespace MyGUI
 
 	void ItemBox::removeDropItems()
 	{
-		if (mItemDrag) mItemDrag->setVisible(false);
+		if (mItemDrag)
+			mItemDrag->setVisible(false);
 	}
 
 	void ItemBox::updateDropItems()
@@ -563,13 +564,19 @@ namespace MyGUI
 			mPointDragOffset = coord.point();
 
 			// создаем и запрашиваем детей
-			mItemDrag = Gui::getInstance().createWidget<Widget>("Default", IntCoord(0, 0, coord.width, coord.height), Align::Default, mDragLayer);
+			mItemDrag = Gui::getInstance().createWidget<Widget>(
+				"Default",
+				IntCoord(0, 0, coord.width, coord.height),
+				Align::Default,
+				mDragLayer);
 			requestCreateWidgetItem(this, mItemDrag);
 		}
 
 		const IntPoint& point = InputManager::getInstance().getMousePosition();
 
-		mItemDrag->setPosition(point.left - mClickInWidget.left + mPointDragOffset.left, point.top - mClickInWidget.top + mPointDragOffset.top);
+		mItemDrag->setPosition(
+			point.left - mClickInWidget.left + mPointDragOffset.left,
+			point.top - mClickInWidget.top + mPointDragOffset.top);
 		mItemDrag->setVisible(true);
 	}
 
@@ -598,7 +605,7 @@ namespace MyGUI
 	{
 		mouseButtonPressed(_id);
 
-		if ( MouseButton::Left == _id)
+		if (MouseButton::Left == _id)
 		{
 			size_t old = mIndexSelect;
 
@@ -617,15 +624,19 @@ namespace MyGUI
 			}
 
 			// смещение внутри виджета, куда кликнули мышкой
-			mClickInWidget = InputManager::getInstance().getLastPressedPosition(MouseButton::Left) - _sender->getAbsolutePosition();
+			mClickInWidget =
+				InputManager::getInstance().getLastPressedPosition(MouseButton::Left) - _sender->getAbsolutePosition();
 
 			// отсылаем событие
 			eventMouseItemActivate(this, mIndexSelect);
 			// смену позиции отсылаем только при реальном изменении
-			if (old != mIndexSelect) eventChangeItemPosition(this, mIndexSelect);
+			if (old != mIndexSelect)
+				eventChangeItemPosition(this, mIndexSelect);
 		}
 
-		eventNotifyItem(this, IBNotifyItemData(getIndexByWidget(_sender), IBNotifyItemData::MousePressed, _left, _top, _id));
+		eventNotifyItem(
+			this,
+			IBNotifyItemData(getIndexByWidget(_sender), IBNotifyItemData::MousePressed, _left, _top, _id));
 	}
 
 	void ItemBox::notifyMouseButtonReleased(Widget* _sender, int _left, int _top, MouseButton _id)
@@ -634,7 +645,9 @@ namespace MyGUI
 		mouseButtonReleased(_id);
 
 		if (needEvent)
-			eventNotifyItem(this, IBNotifyItemData(getIndexByWidget(_sender), IBNotifyItemData::MouseReleased, _left, _top, _id));
+			eventNotifyItem(
+				this,
+				IBNotifyItemData(getIndexByWidget(_sender), IBNotifyItemData::MouseReleased, _left, _top, _id));
 	}
 
 	void ItemBox::notifyRootMouseChangeFocus(Widget* _sender, bool _focus)
@@ -683,11 +696,13 @@ namespace MyGUI
 			mCountItemInLine = _getClientWidget()->getHeight() / mSizeItem.height;
 		}
 
-		if (1 > mCountItemInLine) mCountItemInLine = 1;
+		if (1 > mCountItemInLine)
+			mCountItemInLine = 1;
 
 		// колличество строк
-		mCountLines = mItemsInfo.size() / mCountItemInLine;
-		if (0 != (mItemsInfo.size() % mCountItemInLine)) mCountLines ++;
+		mCountLines = int(mItemsInfo.size() / mCountItemInLine);
+		if (0 != (mItemsInfo.size() % mCountItemInLine))
+			mCountLines++;
 
 		if (mAlignVert)
 		{
@@ -815,22 +830,22 @@ namespace MyGUI
 		endDrop(true);
 	}
 
-	size_t ItemBox::calcIndexByWidget(Widget* _widget)
+	size_t ItemBox::calcIndexByWidget(Widget* _widget) const
 	{
 		return *_widget->_getInternalData<size_t>() + (mFirstVisibleIndex * mCountItemInLine);
 	}
 
-	IntSize ItemBox::getContentSize()
+	IntSize ItemBox::getContentSize() const
 	{
 		return mContentSize;
 	}
 
-	IntPoint ItemBox::getContentPosition()
+	IntPoint ItemBox::getContentPosition() const
 	{
 		return mContentPosition;
 	}
 
-	IntSize ItemBox::getViewSize()
+	IntSize ItemBox::getViewSize() const
 	{
 		return _getClientWidget()->getSize();
 	}
@@ -840,39 +855,29 @@ namespace MyGUI
 		updateMetrics();
 	}
 
-	size_t ItemBox::getHScrollPage()
+	size_t ItemBox::getHScrollPage() const
 	{
 		return mSizeItem.width;
 	}
 
-	size_t ItemBox::getVScrollPage()
+	size_t ItemBox::getVScrollPage() const
 	{
 		return mSizeItem.height;
 	}
 
-	Align ItemBox::getContentAlign()
+	Align ItemBox::getContentAlign() const
 	{
 		return Align::Default;
 	}
 
-	IntRect ItemBox::_getClientAbsoluteRect()
-	{
-		return _getClientWidget()->getAbsoluteRect();
-	}
-
-	Widget* ItemBox::_getClientWidget()
-	{
-		return mClient == nullptr ? this : mClient;
-	}
-
 	size_t ItemBox::getItemCount() const
 	{
 		return mItemsInfo.size();
 	}
 
-	void ItemBox::addItem(Any _data)
+	void ItemBox::addItem(Any _data, bool update)
 	{
-		insertItemAt(ITEM_NONE, _data);
+		insertItemAt(ITEM_NONE, _data, update);
 	}
 
 	size_t ItemBox::getIndexSelected() const
@@ -895,32 +900,47 @@ namespace MyGUI
 		return mAlignVert;
 	}
 
-	Widget* ItemBox::getWidgetDrag()
+	Widget* ItemBox::getWidgetDrag() const
 	{
 		return mItemDrag;
 	}
 
-	void ItemBox::setPosition(int _left, int _top)
+	void ItemBox::setVisibleVScroll(bool _value)
 	{
-		setPosition(IntPoint(_left, _top));
+		mVisibleVScroll = _value;
+		updateFromResize();
 	}
 
-	void ItemBox::setSize(int _width, int _height)
+	void ItemBox::setVisibleHScroll(bool _value)
 	{
-		setSize(IntSize(_width, _height));
+		mVisibleHScroll = _value;
+		updateFromResize();
 	}
 
-	void ItemBox::setCoord(int _left, int _top, int _width, int _height)
+	bool ItemBox::isVisibleVScroll() const
 	{
-		setCoord(IntCoord(_left, _top, _width, _height));
+		return mVisibleVScroll;
 	}
 
-	void ItemBox::setPropertyOverride(const std::string& _key, const std::string& _value)
+	bool ItemBox::isVisibleHScroll() const
 	{
-		/// @wproperty{ItemBox, VerticalAlignment, bool} Вертикальное выравнивание.
+		return mVisibleHScroll;
+	}
+
+	void ItemBox::setPropertyOverride(std::string_view _key, std::string_view _value)
+	{
+		/// @wproperty{ItemBox, VerticalAlignment, bool} Vertical or horizontal alignment.
 		if (_key == "VerticalAlignment")
 			setVerticalAlignment(utility::parseValue<bool>(_value));
 
+		/// @wproperty{ItemBox, VisibleVScroll, bool} Vertical scroll bar visibility.
+		else if (_key == "VisibleVScroll")
+			setVisibleVScroll(utility::parseValue<bool>(_value));
+
+		/// @wproperty{ItemBox, VisibleHScroll, bool} Horizontal scroll bar visibility.
+		else if (_key == "VisibleHScroll")
+			setVisibleHScroll(utility::parseValue<bool>(_value));
+
 		else
 		{
 			Base::setPropertyOverride(_key, _value);
@@ -991,7 +1011,7 @@ namespace MyGUI
 			mHScroll->setScrollPosition(mContentPosition.left);
 	}
 
-	IntPoint ItemBox::getViewOffset()
+	IntPoint ItemBox::getViewOffset() const
 	{
 		return getContentPosition();
 	}
