@@ -17,27 +17,10 @@
 namespace MyGUI
 {
 
-	MultiListBox::MultiListBox() :
-		mHeightButton(0),
-		mWidthBar(0),
-		mWidgetEmpty(nullptr),
-		mLastMouseFocusIndex(ITEM_NONE),
-		mSortUp(true),
-		mSortColumnIndex(ITEM_NONE),
-		mWidthSeparator(0),
-		mItemSelected(ITEM_NONE),
-		mFrameAdvise(false),
-		mClient(nullptr),
-		mHeaderPlace(nullptr)
-	{
-	}
-
 	void MultiListBox::initialiseOverride()
 	{
 		Base::initialiseOverride();
 
-		std::string skinButtonEmpty;
-
 		if (isUserString("SkinButton"))
 			mSkinButton = getUserString("SkinButton");
 
@@ -59,24 +42,20 @@ namespace MyGUI
 		///@wskin_child{MultiListBox, Widget, HeaderPlace} Место для заголовков колонок.
 		assignWidget(mHeaderPlace, "HeaderPlace");
 
-		///@wskin_child{MultiListBox, Widget, Client} Клиентская зона.
-		assignWidget(mClient, "Client");
-		if (mClient != nullptr)
-			setWidgetClient(mClient);
-
-		if (nullptr == mClient)
-			mClient = this;
-
 		///@wskin_child{MultiListBox, Widget, Empty} Виджет для заголовка в месте где нет списков.
 		assignWidget(mWidgetEmpty, "Empty");
 
 		if (mWidgetEmpty == nullptr)
 		{
+			std::string_view skinButtonEmpty;
 			if (isUserString("SkinButtonEmpty"))
 				skinButtonEmpty = getUserString("SkinButtonEmpty");
 
 			if (!skinButtonEmpty.empty())
-				mWidgetEmpty = mClient->createWidget<Widget>(skinButtonEmpty, IntCoord(0, 0, mClient->getWidth(), getButtonHeight()), Align::Default);
+				mWidgetEmpty = _getClientWidget()->createWidget<Widget>(
+					skinButtonEmpty,
+					IntCoord(0, 0, _getClientWidget()->getWidth(), getButtonHeight()),
+					Align::Default);
 		}
 
 		if (getUpdateByResize())
@@ -85,8 +64,6 @@ namespace MyGUI
 
 	void MultiListBox::shutdownOverride()
 	{
-		mClient = nullptr;
-
 		Base::shutdownOverride();
 	}
 
@@ -106,13 +83,13 @@ namespace MyGUI
 		updateColumns();
 	}
 
-	const UString& MultiListBox::getColumnNameAt(size_t _column)
+	const UString& MultiListBox::getColumnNameAt(size_t _column) const
 	{
 		MYGUI_ASSERT_RANGE(_column, mVectorColumnInfo.size(), "MultiListBox::getColumnNameAt");
 		return mVectorColumnInfo[_column].name;
 	}
 
-	int MultiListBox::getColumnWidthAt(size_t _column)
+	int MultiListBox::getColumnWidthAt(size_t _column) const
 	{
 		MYGUI_ASSERT_RANGE(_column, mVectorColumnInfo.size(), "MultiListBox::getColumnWidthAt");
 		return mVectorColumnInfo[_column].width;
@@ -155,9 +132,9 @@ namespace MyGUI
 	void MultiListBox::removeAllItems()
 	{
 		BiIndexBase::removeAllItems();
-		for (VectorColumnInfo::iterator iter = mVectorColumnInfo.begin(); iter != mVectorColumnInfo.end(); ++iter)
+		for (auto& iter : mVectorColumnInfo)
 		{
-			(*iter).list->removeAllItems();
+			iter.list->removeAllItems();
 		}
 
 		mItemSelected = ITEM_NONE;
@@ -167,16 +144,16 @@ namespace MyGUI
 	{
 		if (_index == ITEM_NONE)
 		{
-			for (VectorColumnInfo::iterator iter = mVectorColumnInfo.begin(); iter != mVectorColumnInfo.end(); ++iter)
+			for (auto& iter : mVectorColumnInfo)
 			{
-				(*iter).list->clearIndexSelected();
+				iter.list->clearIndexSelected();
 			}
 		}
 		else
 		{
-			for (VectorColumnInfo::iterator iter = mVectorColumnInfo.begin(); iter != mVectorColumnInfo.end(); ++iter)
+			for (auto& iter : mVectorColumnInfo)
 			{
-				(*iter).list->setIndexSelected(_index);
+				iter.list->setIndexSelected(_index);
 			}
 		}
 	}
@@ -187,7 +164,10 @@ namespace MyGUI
 			return;
 
 		MYGUI_ASSERT(!mVectorColumnInfo.empty(), "MultiListBox::setIndexSelected");
-		MYGUI_ASSERT_RANGE_AND_NONE(_index, mVectorColumnInfo.begin()->list->getItemCount(), "MultiListBox::setIndexSelected");
+		MYGUI_ASSERT_RANGE_AND_NONE(
+			_index,
+			mVectorColumnInfo.begin()->list->getItemCount(),
+			"MultiListBox::setIndexSelected");
 
 		mItemSelected = _index;
 		updateBackSelected(BiIndexBase::convertToBack(mItemSelected));
@@ -205,7 +185,7 @@ namespace MyGUI
 			frameAdvise(true);
 	}
 
-	const UString& MultiListBox::getSubItemNameAt(size_t _column, size_t _index)
+	const UString& MultiListBox::getSubItemNameAt(size_t _column, size_t _index) const
 	{
 		MYGUI_ASSERT_RANGE(_index, mVectorColumnInfo.begin()->list->getItemCount(), "MultiListBox::getSubItemNameAt");
 
@@ -232,21 +212,21 @@ namespace MyGUI
 			return;
 
 		// кнопка, для заполнения пустоты
-		if (mWidthBar >= mClient->getWidth())
+		if (mWidthBar >= _getClientWidget()->getWidth())
 			mWidgetEmpty->setVisible(false);
 		else
 		{
-			mWidgetEmpty->setCoord(mWidthBar, 0, mClient->getWidth() - mWidthBar, getButtonHeight());
+			mWidgetEmpty->setCoord(mWidthBar, 0, _getClientWidget()->getWidth() - mWidthBar, getButtonHeight());
 			mWidgetEmpty->setVisible(true);
 		}
 	}
 
 	void MultiListBox::notifyListChangePosition(ListBox* _sender, size_t _position)
 	{
-		for (VectorColumnInfo::iterator iter = mVectorColumnInfo.begin(); iter != mVectorColumnInfo.end(); ++iter)
+		for (auto& iter : mVectorColumnInfo)
 		{
-			if (_sender != (*iter).list)
-				(*iter).list->setIndexSelected(_position);
+			if (_sender != iter.list)
+				iter.list->setIndexSelected(_position);
 		}
 
 		updateBackSelected(_position);
@@ -263,16 +243,23 @@ namespace MyGUI
 		eventListSelectAccept(this, BiIndexBase::convertToFace(_position));
 	}
 
+	void MultiListBox::notifyListNotifyItem(ListBox* _sender, const MyGUI::IBNotifyItemData& _info)
+	{
+		IBNotifyItemData infoConvertedIndex(_info);
+		infoConvertedIndex.index = BiIndexBase::convertToFace(_info.index);
+		eventNotifyItem(this, infoConvertedIndex);
+	}
+
 	void MultiListBox::notifyListChangeFocus(ListBox* _sender, size_t _position)
 	{
-		for (VectorColumnInfo::iterator iter = mVectorColumnInfo.begin(); iter != mVectorColumnInfo.end(); ++iter)
+		for (auto& iter : mVectorColumnInfo)
 		{
-			if (_sender != (*iter).list)
+			if (_sender != iter.list)
 			{
 				if (ITEM_NONE != mLastMouseFocusIndex)
-					(*iter).list->_setItemFocus(mLastMouseFocusIndex, false);
+					iter.list->_setItemFocus(mLastMouseFocusIndex, false);
 				if (ITEM_NONE != _position)
-					(*iter).list->_setItemFocus(_position, true);
+					iter.list->_setItemFocus(_position, true);
 			}
 		}
 		mLastMouseFocusIndex = _position;
@@ -280,10 +267,10 @@ namespace MyGUI
 
 	void MultiListBox::notifyListChangeScrollPosition(ListBox* _sender, size_t _position)
 	{
-		for (VectorColumnInfo::iterator iter = mVectorColumnInfo.begin(); iter != mVectorColumnInfo.end(); ++iter)
+		for (auto& iter : mVectorColumnInfo)
 		{
-			if (_sender != (*iter).list)
-				(*iter).list->setScrollPosition(_position);
+			if (_sender != iter.list)
+				iter.list->setScrollPosition(_position);
 		}
 	}
 
@@ -296,19 +283,19 @@ namespace MyGUI
 	void MultiListBox::redrawButtons()
 	{
 		size_t pos = 0;
-		for (VectorColumnInfo::iterator iter = mVectorColumnInfo.begin(); iter != mVectorColumnInfo.end(); ++iter)
+		for (auto& iter : mVectorColumnInfo)
 		{
 			if (pos == mSortColumnIndex)
 			{
 				if (mSortUp)
-					(*iter).button->setImageName("Up");
+					iter.button->setImageName("Up");
 				else
-					(*iter).button->setImageName("Down");
+					iter.button->setImageName("Down");
 			}
 			else
-				(*iter).button->setImageName("None");
+				iter.button->setImageName("None");
 
-			(*iter).button->setCaption((*iter).name);
+			iter.button->setCaption(iter.name);
 			pos++;
 		}
 	}
@@ -324,7 +311,7 @@ namespace MyGUI
 		{
 			if (!mFrameAdvise)
 			{
-				MyGUI::Gui::getInstance().eventFrameStart += MyGUI::newDelegate( this, &MultiListBox::frameEntered );
+				MyGUI::Gui::getInstance().eventFrameStart += MyGUI::newDelegate(this, &MultiListBox::frameEntered);
 				mFrameAdvise = true;
 			}
 		}
@@ -332,13 +319,13 @@ namespace MyGUI
 		{
 			if (mFrameAdvise)
 			{
-				MyGUI::Gui::getInstance().eventFrameStart -= MyGUI::newDelegate( this, &MultiListBox::frameEntered );
+				MyGUI::Gui::getInstance().eventFrameStart -= MyGUI::newDelegate(this, &MultiListBox::frameEntered);
 				mFrameAdvise = false;
 			}
 		}
 	}
 
-	Widget* MultiListBox::getSeparator(size_t _index)
+	Widget* MultiListBox::getOrCreateSeparator(size_t _index)
 	{
 		if (!mWidthSeparator || mSkinSeparator.empty())
 			return nullptr;
@@ -348,7 +335,7 @@ namespace MyGUI
 
 		while (_index >= mSeparators.size())
 		{
-			Widget* separator = mClient->createWidget<Widget>(mSkinSeparator, IntCoord(), Align::Default);
+			Widget* separator = _getClientWidget()->createWidget<Widget>(mSkinSeparator, IntCoord(), Align::Default);
 			mSeparators.push_back(separator);
 		}
 
@@ -363,15 +350,15 @@ namespace MyGUI
 		size_t last = mVectorColumnInfo.front().list->getItemCount();
 		if (0 == last)
 			return;
-		last --;
+		last--;
 		size_t first = 0;
 
 		while (first < last)
 		{
 			BiIndexBase::swapItemsBackAt(first, last);
-			for (VectorColumnInfo::iterator iter = mVectorColumnInfo.begin(); iter != mVectorColumnInfo.end(); ++iter)
+			for (auto& iter : mVectorColumnInfo)
 			{
-				(*iter).list->swapItemsAt(first, last);
+				iter.list->swapItemsAt(first, last);
 			}
 
 			first++;
@@ -387,9 +374,33 @@ namespace MyGUI
 		if (mSortUp)
 			std::swap(_left, _right);
 		if (requestOperatorLess.empty())
+		{
 			result = _list->getItemNameAt(_left) < _list->getItemNameAt(_right);
+		}
 		else
-			requestOperatorLess(this, mSortColumnIndex, _list->getItemNameAt(_left), _list->getItemNameAt(_right), result);
+		{
+#ifndef MYGUI_DONT_USE_OBSOLETE
+			requestOperatorLess.m_eventObsolete(
+				this,
+				mSortColumnIndex,
+				_list->getItemNameAt(_left),
+				_list->getItemNameAt(_right),
+				result);
+			requestOperatorLess.m_event(
+				this,
+				mSortColumnIndex,
+				BiIndexBase::convertToFace(_left),
+				BiIndexBase::convertToFace(_right),
+				result);
+#else
+			requestOperatorLess(
+				this,
+				mSortColumnIndex,
+				BiIndexBase::convertToFace(_left),
+				BiIndexBase::convertToFace(_right),
+				result);
+#endif
+		}
 		return result;
 	}
 
@@ -407,7 +418,7 @@ namespace MyGUI
 		// shell sort
 		int first;
 		size_t last;
-		for (size_t step = count >> 1; step > 0 ; step >>= 1)
+		for (size_t step = count >> 1; step > 0; step >>= 1)
 		{
 			for (size_t i = 0; i < (count - step); i++)
 			{
@@ -418,9 +429,9 @@ namespace MyGUI
 					if (compare(list, first, last))
 					{
 						BiIndexBase::swapItemsBackAt(first, last);
-						for (VectorColumnInfo::iterator iter = mVectorColumnInfo.begin(); iter != mVectorColumnInfo.end(); ++iter)
+						for (auto& iter : mVectorColumnInfo)
 						{
-							(*iter).list->swapItemsAt(first, last);
+							iter.list->swapItemsAt(first, last);
 						}
 					}
 					first--;
@@ -443,14 +454,14 @@ namespace MyGUI
 		// если надо, то меняем выделенный элемент
 		// при сортировке, обновится
 		if ((mItemSelected != ITEM_NONE) && (_index <= mItemSelected))
-			mItemSelected ++;
+			mItemSelected++;
 
 		size_t index = BiIndexBase::insertItemAt(_index);
 
 		// вставляем во все поля пустые, а потом присваиваем первому
-		for (VectorColumnInfo::iterator iter = mVectorColumnInfo.begin(); iter != mVectorColumnInfo.end(); ++iter)
+		for (auto& iter : mVectorColumnInfo)
 		{
-			(*iter).list->insertItemAt(index, "");
+			iter.list->insertItemAt(index, UString());
 		}
 		mVectorColumnInfo.front().list->setItemNameAt(index, _name);
 		mVectorColumnInfo.front().list->setItemDataAt(index, _data);
@@ -465,9 +476,9 @@ namespace MyGUI
 
 		size_t index = BiIndexBase::removeItemAt(_index);
 
-		for (VectorColumnInfo::iterator iter = mVectorColumnInfo.begin(); iter != mVectorColumnInfo.end(); ++iter)
+		for (auto& iter : mVectorColumnInfo)
 		{
-			(*iter).list->removeItemAt(index);
+			iter.list->removeItemAt(index);
 		}
 
 		// если надо, то меняем выделенный элемент
@@ -477,9 +488,9 @@ namespace MyGUI
 		else if (mItemSelected != ITEM_NONE)
 		{
 			if (_index < mItemSelected)
-				mItemSelected --;
+				mItemSelected--;
 			else if ((_index == mItemSelected) && (mItemSelected == count))
-				mItemSelected --;
+				mItemSelected--;
 		}
 		updateBackSelected(BiIndexBase::convertToBack(mItemSelected));
 	}
@@ -500,7 +511,7 @@ namespace MyGUI
 	void MultiListBox::setColumnDataAt(size_t _index, Any _data)
 	{
 		MYGUI_ASSERT_RANGE(_index, mVectorColumnInfo.size(), "MultiListBox::setColumnDataAt");
-		mVectorColumnInfo[_index].data = _data;
+		mVectorColumnInfo[_index].data = std::move(_data);
 	}
 
 	void MultiListBox::setSubItemDataAt(size_t _column, size_t _index, Any _data)
@@ -536,7 +547,7 @@ namespace MyGUI
 		setSubItemNameAt(0, _index, _name);
 	}
 
-	const UString& MultiListBox::getItemNameAt(size_t _index)
+	const UString& MultiListBox::getItemNameAt(size_t _index) const
 	{
 		return getSubItemNameAt(0, _index);
 	}
@@ -566,13 +577,13 @@ namespace MyGUI
 		setSubItemDataAt(_column, _index, Any::Null);
 	}
 
-	ListBox* MultiListBox::getSubItemAt(size_t _column)
+	ListBox* MultiListBox::getSubItemAt(size_t _column) const
 	{
 		MYGUI_ASSERT_RANGE(_column, mVectorColumnInfo.size(), "MultiListBox::getSubItemAt");
 		return mVectorColumnInfo[_column].list;
 	}
 
-	size_t MultiListBox::_getItemCount()
+	size_t MultiListBox::_getItemCount() const
 	{
 		return getColumnCount();
 	}
@@ -593,7 +604,7 @@ namespace MyGUI
 		setColumnNameAt(_index, _name);
 	}
 
-	const UString& MultiListBox::_getItemNameAt(size_t _index)
+	const UString& MultiListBox::_getItemNameAt(size_t _index) const
 	{
 		return getColumnNameAt(_index);
 	}
@@ -604,12 +615,12 @@ namespace MyGUI
 		if (_column == ITEM_NONE)
 			_column = mVectorColumnInfo.size();
 
-		createWidget<MultiListItem>("", IntCoord(), Align::Default);
+		createWidget<MultiListItem>(std::string_view{}, IntCoord(), Align::Default);
 
 		mVectorColumnInfo.back().width = _width;
 		mVectorColumnInfo.back().sizeType = ResizingPolicy::Fixed;
 		mVectorColumnInfo.back().name = _name;
-		mVectorColumnInfo.back().data = _data;
+		mVectorColumnInfo.back().data = std::move(_data);
 		mVectorColumnInfo.back().button->setCaption(_name);
 
 		if (_column == (mVectorColumnInfo.size() - 1))
@@ -678,10 +689,10 @@ namespace MyGUI
 		}
 		else
 		{
-			for (VectorColumnInfo::iterator item = mVectorColumnInfo.begin(); item != mVectorColumnInfo.end(); ++item)
+			for (auto& item : mVectorColumnInfo)
 			{
-				if ((*item).button == _widget)
-					(*item).button = nullptr;
+				if (item.button == _widget)
+					item.button = nullptr;
 			}
 		}
 	}
@@ -696,19 +707,24 @@ namespace MyGUI
 
 		ColumnInfo column;
 		column.width = 0;
+		column.realWidth = 0;
 		column.sizeType = ResizingPolicy::Auto;
 
 		column.item = _item;
-		column.list = _item->createWidget<ListBox>(mSkinList, IntCoord(0, 0, _item->getWidth(), _item->getHeight()), Align::Stretch);
+		column.list = _item->createWidget<ListBox>(
+			mSkinList,
+			IntCoord(0, 0, _item->getWidth(), _item->getHeight()),
+			Align::Stretch);
 		column.list->eventListChangePosition += newDelegate(this, &MultiListBox::notifyListChangePosition);
 		column.list->eventListMouseItemFocus += newDelegate(this, &MultiListBox::notifyListChangeFocus);
 		column.list->eventListChangeScroll += newDelegate(this, &MultiListBox::notifyListChangeScrollPosition);
 		column.list->eventListSelectAccept += newDelegate(this, &MultiListBox::notifyListSelectAccept);
+		column.list->eventNotifyItem += newDelegate(this, &MultiListBox::notifyListNotifyItem);
 
 		if (mHeaderPlace != nullptr)
 			column.button = mHeaderPlace->createWidget<Button>(mSkinButton, IntCoord(), Align::Default);
 		else
-			column.button = mClient->createWidget<Button>(mSkinButton, IntCoord(), Align::Default);
+			column.button = _getClientWidget()->createWidget<Button>(mSkinButton, IntCoord(), Align::Default);
 
 		column.button->eventMouseButtonClick += newDelegate(this, &MultiListBox::notifyButtonClick);
 
@@ -717,7 +733,7 @@ namespace MyGUI
 		{
 			size_t count = mVectorColumnInfo.front().list->getItemCount();
 			for (size_t pos = 0; pos < count; ++pos)
-				column.list->addItem("");
+				column.list->addItem(UString());
 		}
 
 		mVectorColumnInfo.push_back(column);
@@ -760,7 +776,7 @@ namespace MyGUI
 			mVectorColumnInfo.back().list->setScrollVisible(true);
 	}
 
-	Widget* MultiListBox::_getItemAt(size_t _index)
+	Widget* MultiListBox::_getItemAt(size_t _index) const
 	{
 		MYGUI_ASSERT_RANGE(_index, mVectorColumnInfo.size(), "MultiListBox::_getItemAt");
 		return mVectorColumnInfo[_index].item;
@@ -771,14 +787,14 @@ namespace MyGUI
 		setColumnNameAt(getColumnIndex(_item), _name);
 	}
 
-	const UString& MultiListBox::getColumnName(MultiListItem* _item)
+	const UString& MultiListBox::getColumnName(const MultiListItem* _item) const
 	{
 		return getColumnNameAt(getColumnIndex(_item));
 	}
 
-	size_t MultiListBox::getColumnIndex(MultiListItem* _item)
+	size_t MultiListBox::getColumnIndex(const MultiListItem* _item) const
 	{
-		for (size_t index = 0; index < mVectorColumnInfo.size(); ++ index)
+		for (size_t index = 0; index < mVectorColumnInfo.size(); ++index)
 		{
 			if (mVectorColumnInfo[index].item == _item)
 				return index;
@@ -825,35 +841,25 @@ namespace MyGUI
 			updateColumns();
 	}
 
-	void MultiListBox::setPosition(int _left, int _top)
-	{
-		setPosition(IntPoint(_left, _top));
-	}
-
-	void MultiListBox::setSize(int _width, int _height)
-	{
-		setSize(IntSize(_width, _height));
-	}
-
-	void MultiListBox::setCoord(int _left, int _top, int _width, int _height)
-	{
-		setCoord(IntCoord(_left, _top, _width, _height));
-	}
-
-	bool MultiListBox::getUpdateByResize()
+	bool MultiListBox::getUpdateByResize() const
 	{
 		if (mWidgetEmpty != nullptr)
 			return true;
 
-		for (VectorColumnInfo::iterator item = mVectorColumnInfo.begin(); item != mVectorColumnInfo.end(); ++item)
+		for (const auto& info : mVectorColumnInfo)
 		{
-			if ((*item).sizeType == ResizingPolicy::Fill)
+			if (info.sizeType == ResizingPolicy::Fill)
 				return true;
 		}
 		return false;
 	}
 
-	int MultiListBox::getColumnWidth(size_t _index, int _freeSpace, size_t _countStars, size_t _lastIndexStar, int _starWidth) const
+	int MultiListBox::getColumnWidth(
+		size_t _index,
+		int _freeSpace,
+		size_t _countStars,
+		size_t _lastIndexStar,
+		int _starWidth) const
 	{
 		const ColumnInfo& info = mVectorColumnInfo[_index];
 
@@ -861,20 +867,17 @@ namespace MyGUI
 		{
 			return info.realWidth;
 		}
-		else if (info.sizeType == ResizingPolicy::Fixed)
+		if (info.sizeType == ResizingPolicy::Fixed)
 		{
 			return info.realWidth;
 		}
-		else if (info.sizeType == ResizingPolicy::Fill)
+		if (info.sizeType == ResizingPolicy::Fill)
 		{
 			if (_lastIndexStar == _index)
 			{
 				return _starWidth + _freeSpace - (_starWidth * _countStars);
 			}
-			else
-			{
-				return _starWidth;
-			}
+			return _starWidth;
 		}
 		return 0;
 	}
@@ -886,22 +889,23 @@ namespace MyGUI
 
 		int width = 0;
 
-		for (size_t index = 0; index < mVectorColumnInfo.size(); ++ index)
+		for (size_t index = 0; index < mVectorColumnInfo.size(); ++index)
 		{
 			ColumnInfo& info = mVectorColumnInfo[index];
 
 			if (info.sizeType == ResizingPolicy::Auto)
 			{
-				info.realWidth = info.button->getWidth() - info.button->getTextRegion().width + info.button->getTextSize().width;
+				info.realWidth =
+					info.button->getWidth() - info.button->getTextRegion().width + info.button->getTextSize().width;
 			}
 			else if (info.sizeType == ResizingPolicy::Fixed)
 			{
-				info.realWidth =  info.width < 0 ? 0 : info.width;
+				info.realWidth = info.width < 0 ? 0 : info.width;
 			}
 			else if (info.sizeType == ResizingPolicy::Fill)
 			{
 				info.realWidth = 0;
-				_countStars ++;
+				_countStars++;
 				_lastIndexStar = index;
 			}
 			else
@@ -921,13 +925,13 @@ namespace MyGUI
 		size_t lastIndexStar = ITEM_NONE;
 
 		int allColumnsWidth = updateWidthColumns(countStars, lastIndexStar);
-		int clientWidth = mClient->getWidth();
+		int clientWidth = _getClientWidget()->getWidth();
 		int separatorsWidth = mVectorColumnInfo.empty() ? 0 : (mVectorColumnInfo.size() - 1) * mWidthSeparator;
 		int freeSpace = clientWidth - separatorsWidth - allColumnsWidth;
 		int starWidth = (countStars != 0 && freeSpace > 0) ? (freeSpace / countStars) : 0;
 
 		mWidthBar = 0;
-		for (size_t index = 0; index < mVectorColumnInfo.size(); ++ index)
+		for (size_t index = 0; index < mVectorColumnInfo.size(); ++index)
 		{
 			ColumnInfo& info = mVectorColumnInfo[index];
 
@@ -935,11 +939,12 @@ namespace MyGUI
 
 			if (mHeaderPlace != nullptr)
 			{
-				info.item->setCoord(mWidthBar, 0, columnWidth, mClient->getHeight());
+				info.item->setCoord(mWidthBar, 0, columnWidth, _getClientWidget()->getHeight());
 			}
 			else
 			{
-				info.item->setCoord(mWidthBar, mHeightButton, columnWidth, mClient->getHeight() - mHeightButton);
+				info.item
+					->setCoord(mWidthBar, mHeightButton, columnWidth, _getClientWidget()->getHeight() - mHeightButton);
 			}
 
 			info.button->setCoord(mWidthBar, 0, columnWidth, getButtonHeight());
@@ -948,10 +953,10 @@ namespace MyGUI
 			mWidthBar += columnWidth;
 
 			// промежуток между листами
-			Widget* separator = getSeparator(index);
+			Widget* separator = getOrCreateSeparator(index);
 			if (separator)
 			{
-				separator->setCoord(mWidthBar, 0, mWidthSeparator, mClient->getHeight());
+				separator->setCoord(mWidthBar, 0, mWidthSeparator, _getClientWidget()->getHeight());
 			}
 
 			mWidthBar += mWidthSeparator;
