@@ -12,20 +12,22 @@
 namespace MyGUI
 {
 
-	template <> RenderManager* Singleton<RenderManager>::msInstance = nullptr;
-	template <> const char* Singleton<RenderManager>::mClassTypeName = "RenderManager";
+	MYGUI_SINGLETON_DEFINITION(RenderManager);
+
+	RenderManager::RenderManager() :
+		mSingletonHolder(this)
+	{
+	}
 
 	bool RenderManager::isFormatSupported(PixelFormat _format, TextureUsage _usage)
 	{
 		return true;
 	}
 
-#if MYGUI_DEBUG_MODE == 1
 	bool RenderManager::checkTexture(ITexture* _texture)
 	{
 		return true;
 	}
-#endif
 
 	void RenderManager::onResizeView(const IntSize& _viewSize)
 	{
