@@ -12,15 +12,6 @@
 namespace MyGUI
 {
 
-	ResourceImageSetPointer::ResourceImageSetPointer() :
-		mImageSet(nullptr)
-	{
-	}
-
-	ResourceImageSetPointer::~ResourceImageSetPointer()
-	{
-	}
-
 	void ResourceImageSetPointer::deserialization(xml::ElementPtr _node, Version _version)
 	{
 		Base::deserialization(_node, _version);
@@ -29,8 +20,8 @@ namespace MyGUI
 		xml::ElementEnumerator info = _node->getElementEnumerator();
 		while (info.next("Property"))
 		{
-			const std::string& key = info->findAttribute("key");
-			const std::string& value = info->findAttribute("value");
+			std::string_view key = info->findAttribute("key");
+			std::string_view value = info->findAttribute("value");
 
 			if (key == "Point")
 				mPoint = IntPoint::parse(value);
