@@ -13,14 +13,6 @@
 namespace MyGUI
 {
 
-	ResourceManualPointer::ResourceManualPointer()
-	{
-	}
-
-	ResourceManualPointer::~ResourceManualPointer()
-	{
-	}
-
 	void ResourceManualPointer::deserialization(xml::ElementPtr _node, Version _version)
 	{
 		Base::deserialization(_node, _version);
@@ -29,13 +21,17 @@ namespace MyGUI
 		xml::ElementEnumerator info = _node->getElementEnumerator();
 		while (info.next("Property"))
 		{
-			const std::string& key = info->findAttribute("key");
-			const std::string& value = info->findAttribute("value");
+			std::string_view key = info->findAttribute("key");
+			std::string_view value = info->findAttribute("value");
 
-			if (key == "Point") mPoint = IntPoint::parse(value);
-			else if (key == "Size") mSize = IntSize::parse(value);
-			else if (key == "Texture") mTexture = value;
-			else if (key == "Coord") mTextureCoord = IntCoord::parse(value);
+			if (key == "Point")
+				mPoint = IntPoint::parse(value);
+			else if (key == "Size")
+				mSize = IntSize::parse(value);
+			else if (key == "Texture")
+				mTexture = value;
+			else if (key == "Coord")
+				mTextureCoord = IntCoord::parse(value);
 		}
 	}
 
