@@ -13,8 +13,7 @@
 namespace MyGUI
 {
 
-	class DirectXDataManager :
-		public DataManager
+	class DirectXDataManager : public DataManager
 	{
 	public:
 		DirectXDataManager();
@@ -32,21 +31,21 @@ namespace MyGUI
 		}
 
 		/** @see DataManager::getData(const std::string& _name) */
-		virtual IDataStream* getData(const std::string& _name);
+		virtual IDataStream* getData(const std::string& _name) const;
 
 		/** @see DataManager::freeData */
 		virtual void freeData(IDataStream* _data);
 
 		/** @see DataManager::isDataExist(const std::string& _name) */
-		virtual bool isDataExist(const std::string& _name);
+		virtual bool isDataExist(const std::string& _name) const;
 
 		/** @see DataManager::getDataListNames(const std::string& _pattern) */
-		virtual const VectorString& getDataListNames(const std::string& _pattern);
+		virtual const VectorString& getDataListNames(const std::string& _pattern) const;
 
 		/** @see DataManager::getDataPath(const std::string& _name) */
-		virtual const std::string& getDataPath(const std::string& _name);
+		std::string getDataPath(const std::string& _name) const override;
 
-	/*internal:*/
+		/*internal:*/
 		void addResourceLocation(const std::string& _name, bool _recursive);
 
 	private:
@@ -55,7 +54,7 @@ namespace MyGUI
 			std::wstring name;
 			bool recursive;
 		};
-		typedef std::vector<ArhivInfo> VectorArhivInfo;
+		using VectorArhivInfo = std::vector<ArhivInfo>;
 		VectorArhivInfo mPaths;
 
 		bool mIsInitialise;
