@@ -19,8 +19,7 @@ struct IDirect3DSurface9;
 namespace MyGUI
 {
 
-	class DirectXRTTexture :
-		public IRenderTarget
+	class DirectXRTTexture : public IRenderTarget
 	{
 	public:
 		DirectXRTTexture(IDirect3DDevice9* _device, IDirect3DTexture9* _texture);
@@ -31,7 +30,7 @@ namespace MyGUI
 
 		virtual void doRender(IVertexBuffer* _buffer, ITexture* _texture, size_t _count);
 
-		virtual const RenderTargetInfo& getInfo()
+		virtual const RenderTargetInfo& getInfo() const override
 		{
 			return mRenderTargetInfo;
 		}
