@@ -10,31 +10,23 @@
 #include "MyGUI_Prerequest.h"
 #include "MyGUI_IVertexBuffer.h"
 
-#include <OgreHardwareBufferManager.h>
-#include <OgreHardwareVertexBuffer.h>
 #include <OgrePrerequisites.h>
 #include <OgreRenderOperation.h>
-#include <OgreRenderSystem.h>
-#include <OgreTextureManager.h>
-#include <OgreTextureUnitState.h>
-
-#include "MyGUI_LastHeader.h"
+#include <OgreHardwareVertexBuffer.h>
 
 namespace MyGUI
 {
 
-	class OgreVertexBuffer :
-		public IVertexBuffer
+	class OgreVertexBuffer : public IVertexBuffer
 	{
 	public:
-		OgreVertexBuffer();
-		virtual ~OgreVertexBuffer();
+		~OgreVertexBuffer() override;
 
-		virtual void setVertexCount(size_t _count);
-		virtual size_t getVertexCount();
+		void setVertexCount(size_t _count) override;
+		size_t getVertexCount() const override;
 
-		virtual Vertex* lock();
-		virtual void unlock();
+		Vertex* lock() override;
+		void unlock() override;
 
 		Ogre::RenderOperation* getRenderOperation()
 		{
@@ -42,13 +34,13 @@ namespace MyGUI
 		}
 
 	private:
-		void createVertexBuffer();
-		void destroyVertexBuffer();
-		void resizeVertexBuffer();
+		void create();
+		void destroy();
+		void resize();
 
 	private:
-		size_t mVertexCount;
-		size_t mNeedVertexCount;
+		size_t mVertexCount{0};
+		size_t mNeedVertexCount{0};
 
 		Ogre::RenderOperation mRenderOperation;
 		Ogre::HardwareVertexBufferSharedPtr mVertexBuffer;
