@@ -13,12 +13,9 @@
 namespace MyGUI
 {
 
-	class OpenGLDataManager :
-		public DataManager
+	class OpenGLDataManager : public DataManager
 	{
 	public:
-		OpenGLDataManager();
-
 		void initialise();
 		void shutdown();
 
@@ -32,21 +29,21 @@ namespace MyGUI
 		}
 
 		/** @see DataManager::getData(const std::string& _name) */
-		virtual IDataStream* getData(const std::string& _name);
+		IDataStream* getData(const std::string& _name) const override;
 
 		/** @see DataManager::freeData */
-		virtual void freeData(IDataStream* _data);
+		void freeData(IDataStream* _data) override;
 
 		/** @see DataManager::isDataExist(const std::string& _name) */
-		virtual bool isDataExist(const std::string& _name);
+		bool isDataExist(const std::string& _name) const override;
 
 		/** @see DataManager::getDataListNames(const std::string& _pattern) */
-		virtual const VectorString& getDataListNames(const std::string& _pattern);
+		const VectorString& getDataListNames(const std::string& _pattern) const override;
 
 		/** @see DataManager::getDataPath(const std::string& _name) */
-		virtual const std::string& getDataPath(const std::string& _name);
+		std::string getDataPath(const std::string& _name) const override;
 
-	/*internal:*/
+		/*internal:*/
 		void addResourceLocation(const std::string& _name, bool _recursive);
 
 	private:
@@ -55,10 +52,10 @@ namespace MyGUI
 			std::wstring name;
 			bool recursive;
 		};
-		typedef std::vector<ArhivInfo> VectorArhivInfo;
+		using VectorArhivInfo = std::vector<ArhivInfo>;
 		VectorArhivInfo mPaths;
 
-		bool mIsInitialise;
+		bool mIsInitialise{false};
 	};
 
 } // namespace MyGUI
