@@ -14,24 +14,24 @@
 #define MYGUI_PLATFORM_LOG(level, text) MYGUI_LOGGING(MYGUI_PLATFORM_LOG_SECTION, level, text)
 
 #define MYGUI_PLATFORM_EXCEPT(dest) \
-{ \
-	MYGUI_PLATFORM_LOG(Critical, dest); \
-	MYGUI_DBG_BREAK;\
-	std::ostringstream stream; \
-	stream << dest << "\n"; \
-	MYGUI_BASE_EXCEPT(stream.str().c_str(), "MyGUI"); \
-}
-
-#define MYGUI_PLATFORM_ASSERT(exp, dest) \
-{ \
-	if ( ! (exp) ) \
+	do \
 	{ \
 		MYGUI_PLATFORM_LOG(Critical, dest); \
-		MYGUI_DBG_BREAK;\
 		std::ostringstream stream; \
 		stream << dest << "\n"; \
 		MYGUI_BASE_EXCEPT(stream.str().c_str(), "MyGUI"); \
-	} \
-}
+	} while (false)
+
+#define MYGUI_PLATFORM_ASSERT(exp, dest) \
+	do \
+	{ \
+		if (!(exp)) \
+		{ \
+			MYGUI_PLATFORM_LOG(Critical, dest); \
+			std::ostringstream stream; \
+			stream << dest << "\n"; \
+			MYGUI_BASE_EXCEPT(stream.str().c_str(), "MyGUI"); \
+		} \
+	} while (false)
 
 #endif // MYGUI_OPENGL_DIAGNOSTIC_H_
