@@ -17,11 +17,15 @@ namespace MyGUI
 	class OpenGLImageLoader
 	{
 	public:
-		OpenGLImageLoader() { }
-		virtual ~OpenGLImageLoader() { }
+		virtual ~OpenGLImageLoader() = default;
 
 		virtual void* loadImage(int& _width, int& _height, PixelFormat& _format, const std::string& _filename) = 0;
-		virtual void saveImage(int _width, int _height, MyGUI::PixelFormat _format, void* _texture, const std::string& _filename) = 0;
+		virtual void saveImage(
+			int _width,
+			int _height,
+			MyGUI::PixelFormat _format,
+			void* _texture,
+			const std::string& _filename) = 0;
 	};
 
 } // namespace MyGUI
