@@ -5,13 +5,12 @@
 */
 
 #include "MyGUI_OpenGLPlatform.h"
-#include <assert.h>
+#include <cassert>
 
 namespace MyGUI
 {
 
-	OpenGLPlatform::OpenGLPlatform() :
-		mIsInitialise(false)
+	OpenGLPlatform::OpenGLPlatform()
 	{
 		mRenderManager = new OpenGLRenderManager();
 		mDataManager = new OpenGLDataManager();
@@ -26,7 +25,7 @@ namespace MyGUI
 		delete mLogManager;
 	}
 
-	void OpenGLPlatform::initialise(OpenGLImageLoader* _loader, const std::string& _logName)
+	void OpenGLPlatform::initialise(OpenGLImageLoader* _loader, std::string_view _logName)
 	{
 		assert(!mIsInitialise);
 		mIsInitialise = true;
@@ -47,15 +46,13 @@ namespace MyGUI
 		mDataManager->shutdown();
 	}
 
-	OpenGLRenderManager* OpenGLPlatform::getRenderManagerPtr()
+	OpenGLRenderManager* OpenGLPlatform::getRenderManagerPtr() const
 	{
-		assert(mIsInitialise);
 		return mRenderManager;
 	}
 
-	OpenGLDataManager* OpenGLPlatform::getDataManagerPtr()
+	OpenGLDataManager* OpenGLPlatform::getDataManagerPtr() const
 	{
-		assert(mIsInitialise);
 		return mDataManager;
 	}
 
