@@ -4,8 +4,7 @@
 #include "KeyboardHook.h"
 #include "HikariWidget.h"
 
-class HookListenerImpl :
-	public HookListener
+class HookListenerImpl : public HookListener
 {
 public:
 	virtual void handleKeyMessage(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam)
