@@ -14,31 +14,26 @@
 namespace plugin
 {
 
-	class Plugin :
-		public MyGUI::IPlugin
+	class Plugin : public MyGUI::IPlugin
 	{
-	public:
-		Plugin();
-		~Plugin();
-
 	public:
 		//!	Initialization
-		virtual void initialize();
+		void initialize() override;
 
 		//!	Installation
-		virtual void install();
+		void install() override;
 
 		//!	Shut down
-		virtual void shutdown();
+		void shutdown() override;
 
 		//!	Uninstall
-		virtual void uninstall();
+		void uninstall() override;
 
 		//! Get name
-		virtual const std::string& getName() const;
+		const std::string& getName() const override;
 
 	private:
-		static const std::string LogSection;
+		static const std::string_view LogSection;
 	};
 
 } // namespace plugin
