@@ -9,15 +9,6 @@
 
 namespace tools
 {
-	Action::Action() :
-		mMerge(false)
-	{
-	}
-
-	Action::~Action()
-	{
-	}
-
 	void Action::doAction()
 	{
 	}
