@@ -14,17 +14,15 @@
 namespace tools
 {
 
-	class MYGUI_EXPORT_DLL ActionChangeDataProperty :
-		public Action
+	class MYGUI_EXPORT_DLL ActionChangeDataProperty : public Action
 	{
 	public:
 		ActionChangeDataProperty();
-		virtual ~ActionChangeDataProperty();
 
 		void setProperty(PropertyPtr _value);
 		PropertyPtr getProperty();
 
-		void setValue(const std::string& _value);
+		void setValue(std::string_view _value);
 		const std::string& getValue() const;
 
 	private:
