@@ -12,17 +12,6 @@
 namespace tools
 {
 
-	ActionChangePositionData::ActionChangePositionData() :
-		mData1(nullptr),
-		mData2(nullptr),
-		mIndex(MyGUI::ITEM_NONE)
-	{
-	}
-
-	ActionChangePositionData::~ActionChangePositionData()
-	{
-	}
-
 	void ActionChangePositionData::doAction()
 	{
 		if (mData1 != mData2 && mData1->getParent() == mData2->getParent())
