@@ -13,18 +13,16 @@
 namespace tools
 {
 
-	class MYGUI_EXPORT_DLL ActionCloneData :
-		public Action
+	class MYGUI_EXPORT_DLL ActionCloneData : public Action
 	{
 	public:
 		ActionCloneData();
-		virtual ~ActionCloneData();
 
-		virtual void doAction();
-		virtual void undoAction();
+		void doAction() override;
+		void undoAction() override;
 
 		void setPrototype(DataPtr _prototype);
-		void setUniqueProperty(const std::string& _value);
+		void setUniqueProperty(std::string_view _value);
 
 	private:
 		std::string mType;
@@ -33,8 +31,8 @@ namespace tools
 		DataPtr mPrototype;
 		std::string mUniqueProperty;
 
-		typedef std::pair<PropertyPtr, std::string> PairProprty;
-		typedef std::vector<PairProprty> VectorPairProperty;
+		using PairProprty = std::pair<PropertyPtr, std::string>;
+		using VectorPairProperty = std::vector<PairProprty>;
 		VectorPairProperty mOldValues;
 	};
 
