@@ -12,15 +12,10 @@
 namespace tools
 {
 
-	class MYGUI_EXPORT_DLL AreaSelectorControl :
-		public SelectorControl
+	class MYGUI_EXPORT_DLL AreaSelectorControl : public SelectorControl
 	{
-	public:
-		AreaSelectorControl();
-		virtual ~AreaSelectorControl();
-
 	protected:
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, std::string_view _layoutName) override;
 	};
 
 }
