@@ -13,26 +13,23 @@
 namespace tools
 {
 
-	class MYGUI_EXPORT_DLL BackgroundControl :
-		public Control,
-		public sigslot::has_slots<>
+	class MYGUI_EXPORT_DLL BackgroundControl : public Control, public sigslot::has_slots<>
 	{
 	public:
-		BackgroundControl();
-		virtual ~BackgroundControl();
+		~BackgroundControl() override;
 
 		MyGUI::Widget* getCanvas();
 
 	protected:
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, std::string_view _layoutName) override;
 
 	private:
 		void setColour(const MyGUI::Colour& _colour);
-		void notifySettingsChanged(const std::string& _path);
+		void notifySettingsChanged(std::string_view _path);
 
 	private:
-		MyGUI::Widget* mBackground;
-		MyGUI::Widget* mCanvas;
+		MyGUI::Widget* mBackground{nullptr};
+		MyGUI::Widget* mCanvas{nullptr};
 		std::string mColourValueName;
 	};
 
