@@ -13,16 +13,12 @@
 namespace tools
 {
 
-	class MYGUI_EXPORT_DLL ChangeValueAction :
-		public ActionChangeDataProperty
+	class MYGUI_EXPORT_DLL ChangeValueAction : public ActionChangeDataProperty
 	{
 	public:
-		ChangeValueAction();
-		virtual ~ChangeValueAction();
-
-		virtual void doAction();
-		virtual void undoAction();
-		virtual bool doMerge(Action* _action);
+		void doAction() override;
+		void undoAction() override;
+		bool doMerge(Action* _action) override;
 
 	private:
 		std::string mOldValue;
