@@ -7,19 +7,9 @@
 #include "Precompiled.h"
 #include "CommandManager.h"
 
-template <> tools::CommandManager* MyGUI::Singleton<tools::CommandManager>::msInstance = nullptr;
-template <> const char* MyGUI::Singleton<tools::CommandManager>::mClassTypeName = "CommandManager";
-
 namespace tools
 {
-
-	CommandManager::CommandManager()
-	{
-	}
-
-	CommandManager::~CommandManager()
-	{
-	}
+	MYGUI_SINGLETON_DEFINITION(CommandManager);
 
 	void CommandManager::initialise()
 	{
@@ -27,8 +17,8 @@ namespace tools
 
 	void CommandManager::shutdown()
 	{
-		for (MapEvent::iterator iter = mEvents.begin(); iter != mEvents.end(); iter++)
-			delete iter->second;
+		for (auto& event : mEvents)
+			delete event.second;
 
 		mEvents.clear();
 	}
