@@ -13,17 +13,19 @@
 namespace tools
 {
 
-	class MYGUI_EXPORT_DLL CommandManager :
-		public MyGUI::Singleton<CommandManager>
+	class MYGUI_EXPORT_DLL CommandManager
 	{
-	public:
-		CommandManager();
-		virtual ~CommandManager();
+		MYGUI_SINGLETON_DECLARATION(CommandManager);
 
+	public:
+		CommandManager() :
+			mSingletonHolder(this)
+		{
+		}
 		void initialise();
 		void shutdown();
 
-		typedef sigslot::signal2<const MyGUI::UString&, bool&> EventType;
+		using EventType = sigslot::signal2<const MyGUI::UString&, bool&>;
 		EventType* getEvent(const MyGUI::UString& _command);
 
 		bool executeCommand(const MyGUI::UString& _command);
@@ -33,7 +35,7 @@ namespace tools
 
 	private:
 		MyGUI::UString mData;
-		typedef std::map<MyGUI::UString, EventType*> MapEvent;
+		using MapEvent = std::map<MyGUI::UString, EventType*>;
 		MapEvent mEvents;
 	};
 
