@@ -11,15 +11,10 @@
 
 namespace tools
 {
-	class MYGUI_EXPORT_DLL ControlDebug :
-		public Control
+	class MYGUI_EXPORT_DLL ControlDebug : public Control
 	{
-	public:
-		ControlDebug();
-		virtual ~ControlDebug();
-
 	protected:
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		using Control::OnInitialise;
 	};
 
 }
