@@ -10,28 +10,20 @@
 namespace tools
 {
 
-	DataType::DataType()
-	{
-	}
-
-	DataType::~DataType()
-	{
-	}
-
 	void DataType::deserialization(pugi::xml_node _node)
 	{
 		mName = _node.select_single_node("Name").node().child_value();
 		mFriend = _node.select_single_node("Friend").node().child_value();
 
 		pugi::xpath_node_set childs = _node.select_nodes("Childs/Child/Type");
-		for (pugi::xpath_node_set::const_iterator child = childs.begin(); child != childs.end(); child ++)
-			mChilds.push_back((*child).node().child_value());
+		for (const auto& child : childs)
+			mChilds.emplace_back(child.node().child_value());
 
 		pugi::xpath_node_set properties = _node.select_nodes("Properties/Property");
-		for (pugi::xpath_node_set::const_iterator property = properties.begin(); property != properties.end(); property ++)
+		for (const auto& property : properties)
 		{
 			DataTypePropertyPtr info(new DataTypeProperty());
-			info->deserialization((*property).node());
+			info->deserialization(property.node());
 			mProperties.push_back(info);
 		}
 	}
@@ -56,11 +48,11 @@ namespace tools
 		return mProperties;
 	}
 
-	bool DataType::isChild(const std::string& _child) const
+	bool DataType::isChild(std::string_view _child) const
 	{
-		for (VectorString::const_iterator child = mChilds.begin(); child != mChilds.end(); child ++)
+		for (const auto& child : mChilds)
 		{
-			if ((*child) == _child)
+			if (child == _child)
 				return true;
 		}
 
