@@ -11,16 +11,6 @@
 namespace tools
 {
 
-	Dialog::Dialog() :
-		mModal(false),
-		mRootWidget(nullptr)
-	{
-	}
-
-	Dialog::~Dialog()
-	{
-	}
-
 	void Dialog::doModal()
 	{
 		MYGUI_ASSERT(mModal != true, "Already modal mode");
@@ -54,7 +44,7 @@ namespace tools
 		mRootWidget = _root;
 	}
 
-	bool Dialog::isDialogModal()
+	bool Dialog::isDialogModal() const
 	{
 		return mModal;
 	}
