@@ -16,11 +16,10 @@ namespace tools
 	class MYGUI_EXPORT_DLL Dialog
 	{
 	public:
-		Dialog();
-		virtual ~Dialog();
+		virtual ~Dialog() = default;
 
 		void setDialogRoot(MyGUI::Widget* _root);
-		bool isDialogModal();
+		bool isDialogModal() const;
 
 		void doModal();
 		void endModal();
@@ -28,12 +27,16 @@ namespace tools
 		sigslot::signal2<Dialog*, bool> eventEndDialog;
 
 	protected:
-		virtual void onDoModal() { }
-		virtual void onEndModal() { }
+		virtual void onDoModal()
+		{
+		}
+		virtual void onEndModal()
+		{
+		}
 
 	private:
-		bool mModal;
-		MyGUI::Widget* mRootWidget;
+		bool mModal{false};
+		MyGUI::Widget* mRootWidget{nullptr};
 	};
 
 }
