@@ -15,12 +15,12 @@
 namespace tools
 {
 
-	class MYGUI_EXPORT_DLL ExportManager :
-		public MyGUI::Singleton<ExportManager>
+	class MYGUI_EXPORT_DLL ExportManager
 	{
+		MYGUI_SINGLETON_DECLARATION(ExportManager);
+
 	public:
 		ExportManager();
-		virtual ~ExportManager();
 
 		void initialise();
 		void shutdown();
@@ -29,7 +29,7 @@ namespace tools
 		bool deserialization(pugi::xml_document& _doc);
 
 	private:
-		IExportSerializer* mExportSerializer;
+		IExportSerializer* mExportSerializer{nullptr};
 	};
 
 }
