@@ -15,36 +15,28 @@ namespace components
 		return *GetInstancePtr();
 	}
 
-	FactoryManager::FactoryManager()
-	{
-	}
-
-	FactoryManager::~FactoryManager()
-	{
-	}
-
-	bool FactoryManager::ExistFactory(const std::string& _factoryName)
+	bool FactoryManager::ExistFactory(std::string_view _factoryName)
 	{
 		return mFactories.find(_factoryName) != mFactories.end();
 	}
 
-	void FactoryManager::RegisterFactory(IFactory* _factory, const std::string& _factoryName)
+	void FactoryManager::RegisterFactory(IFactory* _factory, std::string_view _factoryName)
 	{
-		mFactories[_factoryName] = _factory;
+		MyGUI::mapSet(mFactories, _factoryName, _factory);
 	}
 
-	IFactoryItem* FactoryManager::CreateItem(const std::string& _factoryName)
+	IFactoryItem* FactoryManager::CreateItem(std::string_view _factoryName)
 	{
 		MapFactory::iterator item = mFactories.find(_factoryName);
 		if (item != mFactories.end())
 			return (*item).second->CreateItem();
-		return 0;
+		return nullptr;
 	}
 
 	void FactoryManager::UnregisterAllFactories()
 	{
-		for (MapFactory::iterator factory = mFactories.begin(); factory != mFactories.end(); factory ++)
-			delete (*factory).second;
+		for (auto& factory : mFactories)
+			delete factory.second;
 		mFactories.clear();
 	}
 }
