@@ -8,18 +8,12 @@
 #include "GridManager.h"
 #include "SettingsManager.h"
 
-template <> tools::GridManager* MyGUI::Singleton<tools::GridManager>::msInstance = nullptr;
-template <> const char* MyGUI::Singleton<tools::GridManager>::mClassTypeName = "GridManager";
-
 namespace tools
 {
+	MYGUI_SINGLETON_DEFINITION(GridManager);
 
 	GridManager::GridManager() :
-		mGridStep(0)
-	{
-	}
-
-	GridManager::~GridManager()
+		mSingletonHolder(this)
 	{
 	}
 
@@ -34,7 +28,7 @@ namespace tools
 		SettingsManager::getInstance().eventSettingsChanged.disconnect(this);
 	}
 
-	void GridManager::notifySettingsChanged(const std::string& _path)
+	void GridManager::notifySettingsChanged(std::string_view _path)
 	{
 		if (_path == "Settings/GridStep")
 		{
@@ -49,9 +43,9 @@ namespace tools
 
 		if (_line == Closest)
 			return (_value + mGridStep / 2) / mGridStep * mGridStep;
-		else if (_line == Previous)
+		if (_line == Previous)
 			return (_value - 1) / mGridStep * mGridStep;
-		else if (_line == Next)
+		if (_line == Next)
 			return (_value + mGridStep) / mGridStep * mGridStep;
 
 		return _value;
