@@ -10,15 +10,10 @@
 namespace tools
 {
 
-	HorizontalSelectorControl::HorizontalSelectorControl()
-	{
-	}
-
-	HorizontalSelectorControl::~HorizontalSelectorControl()
-	{
-	}
-
-	void HorizontalSelectorControl::OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName)
+	void HorizontalSelectorControl::OnInitialise(
+		Control* _parent,
+		MyGUI::Widget* _place,
+		std::string_view /*_layoutName*/)
 	{
 		SelectorControl::OnInitialise(_parent, _place, "HorizontalSelectorControl.layout");
 		setPropertyColour("ColourSelector");
