@@ -12,13 +12,9 @@
 namespace tools
 {
 	class Control;
-	class MYGUI_EXPORT_DLL IControlController :
-		public components::IFactoryItem
+	class MYGUI_EXPORT_DLL IControlController : public components::IFactoryItem
 	{
 	public:
-		IControlController() { }
-		virtual ~IControlController() { }
-
 		virtual void setTarget(Control* _control) = 0;
 
 		virtual void activate() = 0;
