@@ -13,17 +13,22 @@
 namespace tools
 {
 
-	class MYGUI_EXPORT_DLL MessageBoxManager :
-		public MyGUI::Singleton<MessageBoxManager>
+	class MYGUI_EXPORT_DLL MessageBoxManager
 	{
-	public:
-		MessageBoxManager();
-		virtual ~MessageBoxManager();
+		MYGUI_SINGLETON_DECLARATION(MessageBoxManager);
 
+	public:
+		MessageBoxManager() :
+			mSingletonHolder(this)
+		{
+		}
 		void initialise();
 		void shutdown();
 
-		MyGUI::Message* create(const MyGUI::UString& _caption, const MyGUI::UString& _message, MyGUI::MessageBoxStyle _style);
+		MyGUI::Message* create(
+			const MyGUI::UString& _caption,
+			const MyGUI::UString& _message,
+			MyGUI::MessageBoxStyle _style);
 		bool hasAny();
 		void endTop(MyGUI::MessageBoxStyle _button);
 
@@ -32,7 +37,7 @@ namespace tools
 		void notifMessageBoxResultRegister(MyGUI::Message* _sender, MyGUI::MessageBoxStyle _result);
 
 	private:
-		typedef std::vector<MyGUI::Message*> VectorMessage;
+		using VectorMessage = std::vector<MyGUI::Message*>;
 		VectorMessage mMessages;
 	};
 
