@@ -13,19 +13,17 @@
 namespace MyGUI
 {
 
-	class MYGUI_EXPORT_DLL FilterNone :
-		public SubSkin
+	class MYGUI_EXPORT_DLL FilterNone : public SubSkin
 	{
-		MYGUI_RTTI_DERIVED( FilterNone )
+		MYGUI_RTTI_DERIVED(FilterNone)
 
 	public:
 		FilterNone();
-		virtual ~FilterNone();
 
-		virtual void doManualRender(IVertexBuffer* _buffer, ITexture* _texture, size_t _count);
+		void doManualRender(IVertexBuffer* _buffer, ITexture* _texture, size_t _count) override;
 
-	/*internal:*/
-		virtual void _setAlign(const IntSize& _oldsize);
+		/*internal:*/
+		void _setAlign(const IntSize& _oldsize) override;
 	};
 
 }
