@@ -10,15 +10,10 @@
 namespace tools
 {
 
-	PositionSelectorControl::PositionSelectorControl()
-	{
-	}
-
-	PositionSelectorControl::~PositionSelectorControl()
-	{
-	}
-
-	void PositionSelectorControl::OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName)
+	void PositionSelectorControl::OnInitialise(
+		Control* _parent,
+		MyGUI::Widget* _place,
+		std::string_view /*_layoutName*/)
 	{
 		SelectorControl::OnInitialise(_parent, _place, "PositionSelectorControl.layout");
 		setPropertyColour("ColourSelector");
