@@ -12,17 +12,15 @@
 namespace tools
 {
 
-	class MYGUI_EXPORT_DLL PropertyInt4Control :
-		public PropertyControl
+	class MYGUI_EXPORT_DLL PropertyInt4Control : public PropertyControl
 	{
 	public:
-		PropertyInt4Control();
-		virtual ~PropertyInt4Control();
+		~PropertyInt4Control() override;
 
 	protected:
-		virtual void updateCaption();
-		virtual void updateProperty();
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		void updateCaption() override;
+		void updateProperty() override;
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, std::string_view _layoutName) override;
 
 	private:
 		void notifyEditTextChange(MyGUI::EditBox* _sender);
@@ -32,8 +30,8 @@ namespace tools
 		void setColour(bool _validate);
 
 	private:
-		MyGUI::TextBox* mName;
-		MyGUI::EditBox* mEdit;
+		MyGUI::TextBox* mName{nullptr};
+		MyGUI::EditBox* mEdit{nullptr};
 	};
 
 }
