@@ -12,14 +12,14 @@
 namespace tools
 {
 
-	class MYGUI_EXPORT_DLL RecentFilesManager :
-		public MyGUI::Singleton<RecentFilesManager>
+	class MYGUI_EXPORT_DLL RecentFilesManager
 	{
+		MYGUI_SINGLETON_DECLARATION(RecentFilesManager);
+
 	public:
-		typedef std::vector<MyGUI::UString> VectorUString;
+		using VectorUString = std::vector<MyGUI::UString>;
 
 		RecentFilesManager();
-		virtual ~RecentFilesManager();
 
 		void initialise();
 		void shutdown();
@@ -39,9 +39,9 @@ namespace tools
 	private:
 		MyGUI::UString mRecentFolder;
 		VectorUString mRecentFolders;
-		size_t mMaxRecentFolders;
+		size_t mMaxRecentFolders{0};
 		VectorUString mRecentFiles;
-		size_t mMaxRecentFiles;
+		size_t mMaxRecentFiles{0};
 	};
 
 }
