@@ -13,17 +13,10 @@
 namespace tools
 {
 
-	class MYGUI_EXPORT_DLL SettingsWindow :
-		public Dialog,
-		public Control,
-		public sigslot::has_slots<>
+	class MYGUI_EXPORT_DLL SettingsWindow : public Dialog, public Control, public sigslot::has_slots<>
 	{
-	public:
-		SettingsWindow();
-		virtual ~SettingsWindow();
-
 	protected:
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, std::string_view _layoutName) override;
 
 	private:
 		bool checkCommand();
@@ -34,8 +27,8 @@ namespace tools
 		void notifyListChangePosition(MyGUI::ListBox* _sender, size_t _index);
 
 	private:
-		MyGUI::ListBox* mListSettings;
-		MyGUI::TabControl* mTabSettings;
+		MyGUI::ListBox* mListSettings{nullptr};
+		MyGUI::TabControl* mTabSettings{nullptr};
 	};
 
 }
