@@ -10,15 +10,10 @@
 namespace tools
 {
 
-	VerticalSelectorBlackControl::VerticalSelectorBlackControl()
-	{
-	}
-
-	VerticalSelectorBlackControl::~VerticalSelectorBlackControl()
-	{
-	}
-
-	void VerticalSelectorBlackControl::OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName)
+	void VerticalSelectorBlackControl::OnInitialise(
+		Control* _parent,
+		MyGUI::Widget* _place,
+		std::string_view /*_layoutName*/)
 	{
 		SelectorControl::OnInitialise(_parent, _place, "VerticalSelectorControl.layout");
 		setPropertyColour("ColourSelectorInactive");
