@@ -14,16 +14,13 @@
 namespace tools
 {
 
-	class FontTryControl :
-		public Control,
-		public sigslot::has_slots<>
+	class FontTryControl : public Control, public sigslot::has_slots<>
 	{
 	public:
-		FontTryControl();
-		virtual ~FontTryControl();
+		~FontTryControl() override;
 
 	protected:
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, std::string_view _layoutName) override;
 
 	private:
 		void commandOnGenerateFont(const MyGUI::UString& _commandName, bool& _result);
@@ -31,7 +28,7 @@ namespace tools
 		void updateFont();
 
 	private:
-		MyGUI::EditBox* mEdit;
+		MyGUI::EditBox* mEdit{nullptr};
 	};
 
 }
