@@ -13,14 +13,10 @@
 namespace tools
 {
 
-	class GenerateFontNamePropertyInitialisator :
-		public IPropertyInitialisator
+	class GenerateFontNamePropertyInitialisator : public IPropertyInitialisator
 	{
 	public:
-		GenerateFontNamePropertyInitialisator();
-		virtual ~GenerateFontNamePropertyInitialisator();
-
-		virtual void initialise(PropertyPtr _property);
+		void initialise(PropertyPtr _property) override;
 	};
 
 }
