@@ -13,21 +13,19 @@
 namespace tools
 {
 
-	class PropertyInt2ListControl :
-		public PropertyControl
+	class PropertyInt2ListControl : public PropertyControl
 	{
 	public:
-		PropertyInt2ListControl();
-		virtual ~PropertyInt2ListControl();
+		~PropertyInt2ListControl() override;
 
 	protected:
-		virtual void updateCaption();
-		virtual void updateProperty();
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		void updateCaption() override;
+		void updateProperty() override;
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, std::string_view _layoutName) override;
 
 	private:
 		std::string getValue();
-		void setValue(const std::string& _value);
+		void setValue(std::string_view _value);
 
 		void notifyClickAdd(MyGUI::Widget* _sender);
 		void notifyClickDelete(MyGUI::Widget* _sender);
@@ -35,12 +33,12 @@ namespace tools
 		void notifyEndDialog(Dialog* _sender, bool _result);
 
 	private:
-		MyGUI::TextBox* mName;
-		MyGUI::ListBox* mList;
-		MyGUI::Button* mAdd;
-		MyGUI::Button* mDelete;
+		MyGUI::TextBox* mName{nullptr};
+		MyGUI::ListBox* mList{nullptr};
+		MyGUI::Button* mAdd{nullptr};
+		MyGUI::Button* mDelete{nullptr};
 
-		TextFieldControl* mTextFieldControl;
+		TextFieldControl* mTextFieldControl{nullptr};
 	};
 
 }
