@@ -13,34 +13,29 @@
 namespace tools
 {
 
-	class FrameTextureController :
-		public IControlController,
-		public sigslot::has_slots<>
+	class FrameTextureController : public IControlController, public sigslot::has_slots<>
 	{
 	public:
-		FrameTextureController();
-		virtual ~FrameTextureController();
+		void setTarget(Control* _control) override;
 
-		virtual void setTarget(Control* _control);
-
-		virtual void activate();
-		virtual void deactivate();
+		void activate() override;
+		void deactivate() override;
 
 	private:
 		void notifyChangeDataSelector(DataPtr _data, bool _changeOnlySelection);
 		void notifyChangeProperty(PropertyPtr _sender);
-		void notifyChangeScope(const std::string& _scope);
-		void notifyChangeValue(const std::string& _value);
+		void notifyChangeScope(std::string_view _scope);
+		void notifyChangeValue(std::string_view _value);
 
-		void updateCoords(const std::string& _value);
+		void updateCoords(std::string_view _value);
 		void updateFrames();
 
 	private:
-		ScopeTextureControl* mControl;
+		ScopeTextureControl* mControl{nullptr};
 		std::string mParentTypeName;
 		std::string mScopeName;
-		DataPtr mParentData;
-		bool mActivated;
+		DataPtr mParentData{nullptr};
+		bool mActivated{false};
 		MyGUI::IntSize mSize;
 		ScopeTextureControl::VectorCoord mFrames;
 	};
