@@ -12,15 +12,10 @@
 namespace tools
 {
 
-	class ImageListControl :
-		public DataListBaseControl
+	class ImageListControl : public DataListBaseControl
 	{
-	public:
-		ImageListControl();
-		virtual ~ImageListControl();
-
 	protected:
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, std::string_view _layoutName) override;
 	};
 
 }
