@@ -13,13 +13,12 @@
 namespace tools
 {
 
-	class EditorToolTip :
-		public wraps::BaseLayout,
-		public MyGUI::Singleton<EditorToolTip>
+	class EditorToolTip : public wraps::BaseLayout
 	{
+		MYGUI_SINGLETON_DECLARATION(EditorToolTip);
+
 	public:
 		EditorToolTip();
-		virtual ~EditorToolTip();
 
 		void initialise();
 		void shutdown();
@@ -32,11 +31,11 @@ namespace tools
 		void setPosition(const MyGUI::IntPoint& _point);
 
 	private:
-		MyGUI::EditBox* mText;
-		MyGUI::Widget* mLastWidget;
+		MyGUI::EditBox* mText{nullptr};
+		MyGUI::Widget* mLastWidget{nullptr};
 
-		int mMinWidth;
-		int mMinHeight;
+		int mMinWidth{0};
+		int mMinHeight{0};
 	};
 
 }
