@@ -6,13 +6,15 @@
 namespace tools
 {
 
-	class GroupMessage :
-		public MyGUI::Singleton<GroupMessage>
+	class GroupMessage
 	{
-	public:
-		GroupMessage();
-		virtual ~GroupMessage();
+		MYGUI_SINGLETON_DECLARATION(GroupMessage);
 
+	public:
+		GroupMessage() :
+			mSingletonHolder(this)
+		{
+		}
 		void initialise();
 		void shutdown();
 
@@ -23,7 +25,7 @@ namespace tools
 		void notifyFrameStarted(float _time);
 
 	private:
-		typedef std::vector<MyGUI::UString> VectorUString;
+		using VectorUString = std::vector<MyGUI::UString>;
 		VectorUString mErrorMessages;
 		VectorUString mWarningMessages;
 	};
