@@ -5,16 +5,10 @@ namespace tools
 {
 
 	MainWorkspaceControl::MainWorkspaceControl(MyGUI::Widget* _parent) :
-		SeparatorPartControl("MainWorkspaceControl.layout", _parent),
-		mToolsControl(nullptr),
-		mWorkspaceControl(nullptr)
+		SeparatorPartControl("MainWorkspaceControl.layout", _parent)
 	{
 		assignBase(mToolsControl, "ToolsControl");
 		assignBase(mWorkspaceControl, "WorkspaceControl");
 	}
 
-	MainWorkspaceControl::~MainWorkspaceControl()
-	{
-	}
-
 }
