@@ -12,12 +12,10 @@
 namespace tools
 {
 
-	class PositionSelectorControlLE :
-		public SelectorControlLE
+	class PositionSelectorControlLE : public SelectorControlLE
 	{
 	public:
 		PositionSelectorControlLE(MyGUI::Widget* _parent);
-		virtual ~PositionSelectorControlLE();
 	};
 
 }
