@@ -21,12 +21,11 @@
 namespace tools
 {
 
-	class PropertiesPanelView :
-		public wraps::BaseLayout
+	class PropertiesPanelView : public wraps::BaseLayout
 	{
 	public:
 		PropertiesPanelView(MyGUI::Widget* _parent = nullptr);
-		virtual ~PropertiesPanelView();
+		~PropertiesPanelView() override;
 
 	private:
 		void notifyChangeSelectedWidget(MyGUI::Widget* _currentWidget);
@@ -38,20 +37,20 @@ namespace tools
 
 	private:
 		MyGUI::IntSize mOldSize;
-		PanelView* mPanelView;
+		PanelView* mPanelView{nullptr};
 
-		PanelMainProperties* mPanelMainProperties;
+		PanelMainProperties* mPanelMainProperties{nullptr};
 
-		typedef std::map<WidgetStyle*, PanelProperties*> MapPropertyWindow;
+		using MapPropertyWindow = std::map<WidgetStyle*, PanelProperties*>;
 		MapPropertyWindow mMapPropertyWindow;
 
-		PanelItems* mPanelItems;
-		PanelUserData* mPanelUserData;
-		PanelControllers* mPanelControllers;
-		PanelTemplateProperties* mPanelTemplateProperties;
-		PanelExtensionProperties* mPanelExtensionProperties;
+		PanelItems* mPanelItems{nullptr};
+		PanelUserData* mPanelUserData{nullptr};
+		PanelControllers* mPanelControllers{nullptr};
+		PanelTemplateProperties* mPanelTemplateProperties{nullptr};
+		PanelExtensionProperties* mPanelExtensionProperties{nullptr};
 
-		MyGUI::Widget* mCurrentWidget;
+		MyGUI::Widget* mCurrentWidget{nullptr};
 	};
 
 }
