@@ -13,15 +13,13 @@
 namespace tools
 {
 
-	class PropertyFieldNumeric :
-		public PropertyFieldEditBox
+	class PropertyFieldNumeric : public PropertyFieldEditBox
 	{
 	public:
 		PropertyFieldNumeric(MyGUI::Widget* _parent);
-		virtual ~PropertyFieldNumeric();
 
 	protected:
-		virtual bool onCheckValue();
+		bool onCheckValue() override;
 	};
 
 }
