@@ -13,15 +13,13 @@
 namespace tools
 {
 
-	class PropertyFieldType :
-		public PropertyFieldComboBox
+	class PropertyFieldType : public PropertyFieldComboBox
 	{
 	public:
 		PropertyFieldType(MyGUI::Widget* _parent);
-		virtual ~PropertyFieldType();
 
 	protected:
-		virtual void onFillValues();
+		void onFillValues() override;
 	};
 
 }
