@@ -14,19 +14,17 @@
 namespace tools
 {
 
-	class TestState :
-		public StateController,
-		public sigslot::has_slots<>
+	class TestState : public StateController, public sigslot::has_slots<>
 	{
 	public:
 		TestState();
-		virtual ~TestState();
+		~TestState() override;
 
-		virtual void initState();
-		virtual void cleanupState();
+		void initState() override;
+		void cleanupState() override;
 
-		virtual void pauseState();
-		virtual void resumeState();
+		void pauseState() override;
+		void resumeState() override;
 
 	private:
 		void commandQuit(const MyGUI::UString& _commandName, bool& _result);
@@ -34,8 +32,8 @@ namespace tools
 		void deleteTestLayout();
 
 	private:
-		MyGUI::xml::Document* mTestLayout;
-		BackgroundControl* mBackgroundControl;
+		MyGUI::xml::Document* mTestLayout{nullptr};
+		BackgroundControl* mBackgroundControl{nullptr};
 	};
 
 }
