@@ -5,18 +5,11 @@ namespace tools
 {
 
 	ToolsControl::ToolsControl(MyGUI::Widget* _parent) :
-		wraps::BaseLayout("ToolsControl.layout", _parent),
-		mPropertiesPanelView(nullptr),
-		mWidgetsWindow(nullptr),
-		mProjectControl(nullptr)
+		wraps::BaseLayout("ToolsControl.layout", _parent)
 	{
 		assignBase(mPropertiesPanelView, "PropertiesControl");
 		assignBase(mWidgetsWindow, "WidgetsControl");
 		assignBase(mProjectControl, "ProjectControl");
 	}
 
-	ToolsControl::~ToolsControl()
-	{
-	}
-
 }
