@@ -13,14 +13,14 @@
 namespace tools
 {
 
-	typedef MyGUI::delegates::CMultiDelegate1<MyGUI::Widget*> Event_ChangeSelectedWidget;
+	using Event_ChangeSelectedWidget = MyGUI::delegates::MultiDelegate<MyGUI::Widget*>;
 
-	class WidgetSelectorManager :
-		public MyGUI::Singleton<WidgetSelectorManager>
+	class WidgetSelectorManager
 	{
+		MYGUI_SINGLETON_DECLARATION(WidgetSelectorManager);
+
 	public:
 		WidgetSelectorManager();
-		virtual ~WidgetSelectorManager();
 
 		void initialise();
 		void shutdown();
@@ -44,8 +44,8 @@ namespace tools
 		MyGUI::Widget* findWidgetSelected(WidgetContainer* _container);
 
 	private:
-		MyGUI::Widget* mCurrentWidget;
-		size_t mSelectDepth;
+		MyGUI::Widget* mCurrentWidget{nullptr};
+		size_t mSelectDepth{0};
 		MyGUI::IntPoint mLastClickPoint;
 		std::string mStoreWidgetTag;
 	};
