@@ -14,19 +14,13 @@
 namespace tools
 {
 
-	class RegionListControl :
-		public Control,
-		public sigslot::has_slots<>
+	class RegionListControl : public Control, public sigslot::has_slots<>
 	{
-	public:
-		RegionListControl();
-		virtual ~RegionListControl();
-
 	protected:
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, std::string_view _layoutName) override;
 
 	private:
-		ListBoxDataControl* mListBoxControl;
+		ListBoxDataControl* mListBoxControl{nullptr};
 	};
 
 }
