@@ -25,16 +25,7 @@ namespace tools
 
 	FACTORY_ITEM_ATTRIBUTE(SeparatorListControl)
 
-	SeparatorListControl::SeparatorListControl() :
-		mListBoxControl(nullptr)
-	{
-	}
-
-	SeparatorListControl::~SeparatorListControl()
-	{
-	}
-
-	void SeparatorListControl::OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName)
+	void SeparatorListControl::OnInitialise(Control* _parent, MyGUI::Widget* _place, std::string_view _layoutName)
 	{
 		Control::OnInitialise(_parent, _place, _layoutName);
 
