@@ -12,15 +12,10 @@
 namespace tools
 {
 
-	class SkinListControl :
-		public DataListBaseControl
+	class SkinListControl : public DataListBaseControl
 	{
-	public:
-		SkinListControl();
-		virtual ~SkinListControl();
-
 	protected:
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, std::string_view _layoutName) override;
 
 	private:
 		void commandCreateImageData(const MyGUI::UString& _commandName, bool& _result);
