@@ -11,14 +11,14 @@
 namespace demo
 {
 
-	class DemoKeeper :
-		public base::BaseDemoManager
+	class DemoKeeper : public base::BaseDemoManager
 	{
 	public:
-		virtual void createScene();
-		virtual void destroyScene();
+		void createScene() override;
+		void destroyScene() override;
 
 		void handleClick_MemberFunction(MyGUI::Widget* _sender);
+		void handleClick_ConstMemberFunction(MyGUI::Widget* _sender) const;
 		static void handleClick_StaticMemberFunction(MyGUI::Widget* _sender);
 	};
 
