@@ -16,16 +16,12 @@ namespace tools
 	{
 	}
 
-	Dialog::Dialog(const std::string& _layout) :
+	Dialog::Dialog(std::string_view _layout) :
 		wraps::BaseLayout(_layout),
 		mModal(false)
 	{
 	}
 
-	Dialog::~Dialog()
-	{
-	}
-
 	void Dialog::doModal()
 	{
 		MYGUI_ASSERT(mModal != true, "Already modal mode");
