@@ -13,28 +13,26 @@
 namespace demo
 {
 
-	class GraphNodeEventController :
-		public BaseAnimationNode
+	class GraphNodeEventController : public BaseAnimationNode
 	{
 	public:
-		GraphNodeEventController(const std::string& _name) :
-			BaseAnimationNode("GraphNodeEvent.layout", "EventController", _name),
-			mConnectionOut(nullptr),
-			mButtonEvent(nullptr)
+		GraphNodeEventController(std::string_view _name) :
+			BaseAnimationNode("GraphNodeEvent.layout", "EventController", _name)
 		{
 		}
 
 	private:
-		virtual void initialise()
+		void initialise() override
 		{
 			mMainWidget->castType<MyGUI::Window>()->setCaption(getName());
 			assignBase(mConnectionOut, "ConnectionOut");
 			assignWidget(mButtonEvent, "ButtonEvent");
 
-			mButtonEvent->eventMouseButtonClick += MyGUI::newDelegate(this, &GraphNodeEventController::notifyMouseButtonClick);
+			mButtonEvent->eventMouseButtonClick +=
+				MyGUI::newDelegate(this, &GraphNodeEventController::notifyMouseButtonClick);
 		}
 
-		virtual void shutdown()
+		void shutdown() override
 		{
 		}
 
@@ -51,9 +49,8 @@ namespace demo
 		}
 
 	private:
-		wraps::BaseGraphConnection* mConnectionOut;
-		MyGUI::Button* mButtonEvent;
-
+		wraps::BaseGraphConnection* mConnectionOut{nullptr};
+		MyGUI::Button* mButtonEvent{nullptr};
 	};
 
 } // namespace demo
