@@ -12,8 +12,7 @@
 namespace demo
 {
 
-	class GraphView :
-		public wraps::BaseGraphView
+	class GraphView : public wraps::BaseGraphView
 	{
 	public:
 		GraphView() :
