@@ -12,14 +12,11 @@
 namespace MyGUI
 {
 
-	class WrapPanel :
-		public Panel
+	class WrapPanel : public Panel
 	{
-		MYGUI_RTTI_DERIVED( WrapPanel )
+		MYGUI_RTTI_DERIVED(WrapPanel)
 
 	public:
-		WrapPanel();
-
 		Align getContentAlign() const;
 		void setContentAlign(Align _value);
 
@@ -33,8 +30,8 @@ namespace MyGUI
 		void setSnapFloat(Align _value);
 
 	protected:
-		virtual IntSize overrideMeasure(const IntSize& _sizeAvailable);
-		virtual void overrideArrange();
+		IntSize overrideMeasure(const IntSize& _sizeAvailable) override;
+		void overrideArrange() override;
 
 	private:
 		void alignChildLine(size_t _startIndex, size_t _stopIndex, const IntCoord& _coordAvailable, int _lineWidth);
@@ -48,7 +45,7 @@ namespace MyGUI
 	private:
 		Align mContentAlign;
 		Align mSnapFloat;
-		bool mContentFloat;
+		bool mContentFloat{false};
 		IntSize mSpacer;
 	};
 
