@@ -11,13 +11,12 @@
 namespace demo
 {
 
-	class DemoKeeper :
-		public base::BaseDemoManager
+	class DemoKeeper : public base::BaseDemoManager
 	{
 	public:
-		virtual void createScene();
-		virtual void destroyScene();
-		virtual void setupResources();
+		void createScene() override;
+		void destroyScene() override;
+		void setupResources() override;
 	};
 
 } // namespace demo
