@@ -13,12 +13,10 @@ namespace demo
 {
 
 	ATTRIBUTE_CLASS_LAYOUT(KeyboardPanel, "Keyboard.layout");
-	class KeyboardPanel :
-		public wraps::BaseLayout
+	class KeyboardPanel : public wraps::BaseLayout
 	{
 	public:
 		KeyboardPanel();
-		virtual ~KeyboardPanel();
 
 	private:
 		void notifyMouseButtonClick(MyGUI::Widget* _sender);
