@@ -12,8 +12,8 @@
 namespace demo
 {
 
-	unittest::UnitTest_List* unittest_list = 0;
-	unittest::UnitTest_MultiList* unittest_multilist = 0;
+	static unittest::UnitTest_List* unittest_list = nullptr;
+	static unittest::UnitTest_MultiList* unittest_multilist = nullptr;
 
 	void DemoKeeper::setupResources()
 	{
@@ -37,16 +37,18 @@ namespace demo
 		MyGUI::Gui::getInstance().eventFrameStart -= MyGUI::newDelegate(this, &DemoKeeper::notifyFrameStarted);
 
 		delete unittest_multilist;
-		unittest_multilist = 0;
+		unittest_multilist = nullptr;
 
 		delete unittest_list;
-		unittest_list = 0;
+		unittest_list = nullptr;
 	}
 
 	void DemoKeeper::notifyFrameStarted(float _time)
 	{
-		if (unittest_list) unittest_list->nextFrame();
-		if (unittest_multilist) unittest_multilist->nextFrame();
+		if (unittest_list)
+			unittest_list->nextFrame();
+		if (unittest_multilist)
+			unittest_multilist->nextFrame();
 
 #if MYGUI_PLATFORM == MYGUI_PLATFORM_WIN32
 		::Sleep(10);
