@@ -11,16 +11,13 @@
 namespace demo
 {
 
-	class DemoKeeper :
-		public base::BaseDemoManager
+	class DemoKeeper : public base::BaseDemoManager
 	{
 	public:
-		DemoKeeper();
-
-		virtual void createScene();
+		void createScene() override;
 
 	private:
-		virtual void setupResources();
+		void setupResources() override;
 
 		void makeBezier(const std::vector<MyGUI::FloatPoint>& _points, size_t _pointsNumber);
 		void updateSpline();
@@ -31,11 +28,11 @@ namespace demo
 		void notifyChangeStroke(MyGUI::ScrollBar* _sender, size_t _position);
 
 	private:
-		MyGUI::Widget* mClient;
+		MyGUI::Widget* mClient{nullptr};
 		std::vector<MyGUI::FloatPoint> mLinePoints;
-		MyGUI::PolygonalSkin* mPolygonalSkin;
-		MyGUI::TextBox* mQualityText;
-		MyGUI::TextBox* mStrokeText;
+		MyGUI::PolygonalSkin* mPolygonalSkin{nullptr};
+		MyGUI::TextBox* mQualityText{nullptr};
+		MyGUI::TextBox* mStrokeText{nullptr};
 		MyGUI::IntPoint mOffset;
 	};
 
