@@ -15,21 +15,17 @@
 namespace demo
 {
 
-	class WobbleNodeAnimator :
-		public MyGUI::LayerNodeAnimation,
-		public Tesselator
+	class WobbleNodeAnimator : public MyGUI::LayerNodeAnimation, public Tesselator
 	{
-		MYGUI_RTTI_DERIVED( WobbleNodeAnimator )
+		MYGUI_RTTI_DERIVED(WobbleNodeAnimator)
 
 	public:
-		WobbleNodeAnimator();
+		void attach(MyGUI::ILayerNode* _node) override;
 
-		virtual void attach(MyGUI::ILayerNode* _node);
+		void create() override;
+		void destroy() override;
 
-		virtual void create();
-		virtual void destroy();
-
-		virtual size_t animate(
+		size_t animate(
 			bool _update,
 			size_t _quad_count,
 			MyGUI::VectorQuadData& _data,
@@ -38,15 +34,14 @@ namespace demo
 			MyGUI::ITexture* _texture,
 			const MyGUI::RenderTargetInfo& _info,
 			const MyGUI::IntCoord& _coord,
-			bool& _isAnimate
-		);
+			bool& _isAnimate) override;
 
 	private:
 		void addInertia(const MyGUI::FloatPoint& _value);
 		void addTime(float _time);
 		void buildQuadVertex(MyGUI::VectorQuadData& _data);
 
-		virtual void deserialization(MyGUI::xml::ElementPtr _node, MyGUI::Version _version);
+		void deserialization(MyGUI::xml::ElementPtr _node, MyGUI::Version _version) override;
 
 	private:
 		MyGUI::IntCoord mOldCoord;
@@ -55,10 +50,10 @@ namespace demo
 		MyGUI::FloatPoint mInertiaPoint;
 		MyGUI::FloatPoint mDragOffset;
 
-		bool mInertiaMode;
-		float mDragStrength;
-		float mResizeStrength;
-		bool mDestroy;
+		bool mInertiaMode{false};
+		float mDragStrength{0.001f};
+		float mResizeStrength{0.0009f};
+		bool mDestroy{true};
 	};
 
 }
