@@ -26,19 +26,19 @@ namespace MyGUI
 		static ExportDataManager* getInstancePtr();
 
 		/** @see DataManager::getData(const std::string& _name) */
-		virtual IDataStream* getData(const std::string& _name);
+		virtual IDataStream* getData(const std::string& _name) const;
 
 		/** @see DataManager::freeData */
 		virtual void freeData(IDataStream* _data);
 
 		/** @see DataManager::isDataExist(const std::string& _name) */
-		virtual bool isDataExist(const std::string& _name);
+		virtual bool isDataExist(const std::string& _name) const;
 
 		/** @see DataManager::getDataListNames(const std::string& _pattern) */
-		virtual const VectorString& getDataListNames(const std::string& _pattern);
+		virtual const VectorString& getDataListNames(const std::string& _pattern) const;
 
 		/** @see DataManager::getDataPath(const std::string& _name) */
-		virtual const std::string& getDataPath(const std::string& _name);
+		std::string getDataPath(const std::string& _name) const override;
 
 	/*internal:*/
 		void addResourceLocation(const std::string& _path, bool _recursive);
@@ -49,7 +49,7 @@ namespace MyGUI
 			std::wstring name;
 			bool recursive;
 		};
-		typedef std::vector<ArhivInfo> VectorArhivInfo;
+		using VectorArhivInfo = std::vector<ArhivInfo>;
 		VectorArhivInfo mPaths;
 	};
 
