@@ -31,7 +31,7 @@ namespace MyGUI
 		mLogManager = nullptr;
 	}
 
-	void ExportPlatform::initialise(const std::string& _logName)
+	void ExportPlatform::initialise(std::string_view _logName)
 	{
 		if (!_logName.empty())
 			LogManager::getInstance().createDefaultSource(_logName);
@@ -46,12 +46,12 @@ namespace MyGUI
 		mDataManager->shutdown();
 	}
 
-	ExportRenderManager* ExportPlatform::getRenderManagerPtr()
+	ExportRenderManager* ExportPlatform::getRenderManagerPtr() const
 	{
 		return mRenderManager;
 	}
 
-	ExportDataManager* ExportPlatform::getDataManagerPtr()
+	ExportDataManager* ExportPlatform::getDataManagerPtr() const
 	{
 		return mDataManager;
 	}
